/*
 *
 * PAM account functions for pam_cifs.
 *   Copyright Elliot Lee, 1996.  All rights reserved.
 *   Copyright Jan Rkorajski, 1999.  All rights reserved.
 *   Copyright (c) International Business Machines  Corp., 2001
 *     IBM Contact: RCHNSSPT@us.ibm.com
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <security/_pam_aconf.h>

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <sys/types.h>
#include <syslog.h>
#include <pwd.h>
#include <shadow.h>
#include <time.h>		/* for time() */

#include <security/_pam_macros.h>

/* indicate that the following groups are defined */

#define PAM_SM_ACCOUNT

#include <security/pam_modules.h>

#ifndef LINUX_PAM
#include <security/pam_appl.h>
#endif				/* LINUX_PAM */

#include "support.h"
#include "pam_cifs_common.h"
#include "pam_cifs_user.h"
 
/*
 * PAM framework looks for this entry-point to pass control to the
 * account management module.
 */

PAM_EXTERN int pam_sm_acct_mgmt(pam_handle_t * pamh, int flags,
				int argc, const char **argv)
{
	unsigned int ctrl;
	const char *uname;
	struct passwd *pwent;
	int retval;
    int rc;
    int expiredFlag;

	D(("called."));

	ctrl = _set_ctrl(pamh, flags, NULL, argc, argv);

	retval = pam_get_item(pamh, PAM_USER, (const void **) &uname);
	D(("user = `%s'", uname));
	if (retval != PAM_SUCCESS || uname == NULL) {
		_log_err(LOG_ALERT, pamh
			 ,"could not identify user (from uid=%d)"
			 ,getuid());
		return PAM_USER_UNKNOWN;
	}

	pwent = getpwnam(uname);
	if (!pwent) {
		_log_err(LOG_ALERT, pamh
			 ,"could not identify user (from getpwnam(%s))"
			 ,uname);
		return PAM_USER_UNKNOWN;
	}

    
    /* If this is not a CIFS user, return success */
	if (strstr(pwent->pw_gecos, CIFS_USER_CIFS_DESC_KEY) == NULL) 
	{
		return PAM_SUCCESS;
	}


    /* Check for an expired password */
    rc = pam_get_data(pamh, CIFS_PAM_DATA_PASSWORD_EXPIRED, (void*)&expiredFlag);
    if(rc == PAM_SUCCESS)
	{
		_log_err(LOG_NOTICE, pamh
			 ,"Password expired for user %s" ,uname);
		_make_remark(pamh, ctrl, PAM_ERROR_MSG,
			    "You are required to change your password");
		D(("need a new password"));
		return PAM_NEW_AUTHTOK_REQD;
	}

	D(("all done"));

	return PAM_SUCCESS;
}


/* static module data */
#ifdef PAM_STATIC
struct pam_module _pam_unix_acct_modstruct = {
    "pam_cifs_acct",
    NULL,
    NULL,
    pam_sm_acct_mgmt,
    NULL,
    NULL,
    NULL,
};
#endif
