/*
 *
 * Functions to read pam_cifs.conf file
 *   Copyright (c) International Business Machines  Corp., 2001
 *     IBM Contact: RCHNSSPT@us.ibm.com
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>

#include <security/_pam_macros.h>
#include <security/pam_modules.h>

#include "support.h"
#include "pam_cifs_common.h"
#include "pam_cifs_config.h"

/* Initialize keyword table */
lookupEntry parmTable[] = PARSE_PARM_TABLE_INIT;

/* Local prototypes */
static int isNumber(const char* num);


/********************************************************************
*
* Determine if a string is a valid integer
*
********************************************************************/
static int isNumber(const char* num)
{
    int i;

    if((num == NULL) || (num[0] == '\0'))
        return FALSE;

    for(i=0; (num[i] != '\0'); i++)
    {
        if(isdigit(num[i]) == 0)
            return(FALSE);
    }

    return TRUE;
}


/********************************************************************
*
* initConfig - Read cifs conf file and initialize parm table.
*
********************************************************************/
int initConfig(pam_handle_t *pamh, const char* configPath)
{
   int   retval;
   char  *value;
   int   validationError=FALSE;

   /* Read and load parm table */
   retval = readParms(configPath, parmTable);
   if(retval != PARSE_ERROR_SUCCESS)
      return CONFIG_ERROR_READ_PARM;

   /* Validate parameters */

   /* Check AuthenticatedLoginType */
   value = parmTable[PARSE_KEY_AUTH_TYPE].value;
   if ((value[0] == '\0') || strcmp(value, PARSE_AUTH_TYPE_SMB))
   {
      _log_err(LOG_ERR, pamh, "Config keyword %s has invalid value \"%s\"\n", 
               parmTable[PARSE_KEY_AUTH_TYPE].keyword, value); 
      validationError = TRUE;
   }

   /* Check SMBDomainName - no check necessary */

   /* Check SMBAuthServer */
   value = parmTable[PARSE_KEY_AUTH_SERVER].value;
   if (value[0] == '\0')
   {
      _log_err(LOG_ERR, pamh, "Config keyword %s has invalid value \"%s\"\n",
               parmTable[PARSE_KEY_AUTH_SERVER].keyword, value); 
      validationError = TRUE;
   }

   /* Check SMBAuthServerAlt - no check necessary */

   /* Check SMBCommonUid */
   value = parmTable[PARSE_KEY_COMMON_UID].value;
   if (!isNumber(value))
   {
      _log_err(LOG_ERR, pamh, "Config keyword %s has invalid value \"%s\"\n",
               parmTable[PARSE_KEY_COMMON_UID].keyword, value); 
      validationError = TRUE;
   }

   /* Check SMBCommonGid */
   value = parmTable[PARSE_KEY_COMMON_GID].value;
   if (!isNumber(value))
   {
      _log_err(LOG_ERR, pamh, "Config keyword %s has invalid value \"%s\"\n", 
               parmTable[PARSE_KEY_COMMON_GID].keyword, value); 
      validationError = TRUE;
   }

   if(validationError)
       return CONFIG_ERROR_VALIDATION;

   return CONFIG_ERROR_SUCCESS;
}


