/*
 *
 * Definitions for reading pam_cifs.conf file.
 *   Copyright (c) International Business Machines  Corp., 2001
 *     IBM Contact: RCHNSSPT@us.ibm.com
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _pam_cifs_config_h_
#define _pam_cifs_config_h_

#include "prop_parse.h"

/* Global definitions for pam_cifs */

extern lookupEntry parmTable[];

/* Config file parameter tables for pam_cifs */

/* Index constants for keyword table. */
/* Note: This list must be in the same order as the parm table! */
typedef enum {
    PARSE_KEY_AUTH_TYPE = 0,
    PARSE_KEY_DOMAIN,
    PARSE_KEY_AUTH_SERVER,
    PARSE_KEY_AUTH_SERVER_ALT,
    PARSE_KEY_COMMON_UID,
    PARSE_KEY_COMMON_GID,
    PARSE_KEY_TOTAL
} keywordEnum;

/* AuthenticatedLoginType values */
#define PARSE_AUTH_TYPE_LOCAL "0"
#define PARSE_AUTH_TYPE_NIS   "1"
#define PARSE_AUTH_TYPE_SMB   "2"

/* Initialize keyword table */
#define PARSE_PARM_TABLE_INIT \
{ \
    {"AuthenticatedLoginType",  PARSE_AUTH_TYPE_SMB,    0}, \
    {"SMBDomainName",           "",                     0}, \
    {"SMBAuthServer",           "",                     0}, \
    {"SMBAuthServerAlt",        "",                     0}, \
    {"SMBCommonUid",            "65001",                0}, \
    {"SMBCommonGid",            "65001",                0}, \
    {NULL, "", 0} \
}


/* Error constants */
typedef enum {
    CONFIG_ERROR_SUCCESS        = 0,
    CONFIG_ERROR_UNKNOWN        = 1,
    CONFIG_ERROR_READ_PARM      = 2,
    CONFIG_ERROR_VALIDATION     = 3
} configErrorCodes;

/* Constants */
#define CIFS_CONFIG_PATH "/etc/pam_cifs.conf"

#define CIFS_CONFIG_COPY_SKEL_CMD "cp -dR /etc/skel %.64s"
#define CIFS_CONFIG_SET_OWNER_CMD "chown -R %d.%d %.64s"

/* Prototypes */
int initConfig(pam_handle_t *pamh, const char* configPath);

#endif

