/*
 *
 * Add a CIFS user to special passwd cache file.
 *   Copyright (c) International Business Machines  Corp., 2001
 *     IBM Contact: RCHNSSPT@us.ibm.com
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>

#include <errno.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <unistd.h>
#include <pwd.h>

#include "pam_cifs_common.h"
#include "pam_cifs_user.h"

/* Global Data */
char    *passwdPath = CIFS_USER_PASSWD_PATH;

/* Test if string contains all lower case chars */
int cifsIsLower(const char *str)
{
    int i;

    if(str == NULL)
        return FALSE;

    for (i=0; (str[i] != '\0'); i++)
    {
        if(str[i] != tolower(str[i]))
            return FALSE;
    }

    return TRUE;
}

/* Append a passwd entry to local cached passwd file */
int append_user(struct passwd *userEntry)
{
    FILE        *pwFile;
    struct stat fileInfo;
    int         rc;
    int         setPerm;
    int         savedMask;

    /* Determine if passwd file already exists */
    rc = stat(passwdPath, &fileInfo);
    setPerm = ((rc != 0) && (errno == ENOENT));

    /* Attempt to open or create passwd file */
    savedMask = umask(077);
    pwFile = fopen(passwdPath, "a");
    umask(savedMask);

    if(pwFile == NULL)
        return(CIFS_USER_ERROR_FILE_OPEN);

    if(setPerm)
    {
        /* Fix up permissions if file was just created */
        chown(passwdPath, 0, 0);
        chmod(passwdPath, 0644);
    }

    /* Write user entry to passwd file */
    fprintf(pwFile, "%s:%s:%d:%d:%s:%s:%s\n", userEntry->pw_name,
            userEntry->pw_passwd, userEntry->pw_uid, userEntry->pw_gid,
            userEntry->pw_gecos, userEntry->pw_dir, userEntry->pw_shell);

    rc = fclose(pwFile);
    if (rc != 0)
    {
        /* Indicate a file I/O error */
        return CIFS_USER_ERROR_FILE_IO;
    }


    return CIFS_USER_ERROR_SUCCESS;
}

