/*
 *
 * Definitions for generic table driven parsing code.
 *   Copyright (c) International Business Machines  Corp., 2001
 *     IBM Contact: RCHNSSPT@us.ibm.com
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _prop_parse_h_
#define _prop_parse_h_

/* Parm table entry */
#define PARSE_VALUE_SIZE 128
typedef struct {
    char*   keyword;
    char    value[PARSE_VALUE_SIZE];
    int     flags;      /* Not currently used */
} lookupEntry;

/* Error constants */
typedef enum {
    PARSE_ERROR_SUCCESS             = 0,
    PARSE_ERROR_UNKNOWN             = 1,
    PARSE_ERROR_OPEN_FILE           = 2,
    PARSE_ERROR_UNKNOWN_KEYWORD     = 3,
    PARSE_ERROR_SYNTAX              = 4,
    PARSE_ERROR_COMMENT             = 5,
    PARSE_ERROR_NO_MEMORY           = 6
} parseErrorCodes;


/* Public prototypes */
int readParms(const char *configFilePath, lookupEntry parmTable[]);

/* The following is an example of the parmTable initialization */
#if 0
/* Index constants for keyword table. */
/* Note: This list must be in the same order as the parm table! */
typedef enum {
    PARSE_KEY_AUTH_TYPE = 0,
    PARSE_KEY_DOMAIN,
    PARSE_KEY_AUTH_SERVER,
    PARSE_KEY_AUTH_SERVER_ALT,
    PARSE_KEY_COMMON_UID,
    PARSE_KEY_COMMON_GID,
    PARSE_KEY_TOTAL
} keywordEnum;

/* Initialize keyword table */
lookupEntry parmTable[] = {
    {"AuthenticatedLoginType",  "",     0},
    {"SMBDomainName",           "",     0},
    {"SMBAuthServer",           "",     0},
    {"SMBAuthServerAlt",        "",     0},
    {"SMBCommonUid",            "65000", 0},
    {"SMBCommonGid",            "100",  0},
    {NULL, "", 0}

};
#endif

#endif

