#!/bin/bash
#set -x

# InstallFlashImage.sh
# 
# Start up script that will query user for a bootserver and
# mount point, mount the server, look for FlashImages, (IDFs)
# and present a list of the IDFs and prompt the user to select
# which image they want to install to their flash. Once an 
# image is selected, it will call a script to partition, format
# and mount the flash to /mnt/hd1, and then call "lcma", the
# update binary to update the mounted flash with the IDF the
# user selected.
#
#


function chooseLocalRemote
{
	echo -n "Use current boot server?([y]/n): "; read -r input
        case $input in
                ""|[yY]|[yY][eE][sS]) 
                   USINGEXISTINGFS=y
                   ;;
		[nN]|[nN][oO])
                   USINGEXISTINGFS=n
                   ;;
		*)
			echo -e "\nInvalid Response\n"
			chooseLocalRemote;;
	esac
}

function getBootServer 
{
	echo -n "What is the IP of your recovery server?: "; read -r BOOTSERVER
	check_valid $BOOTSERVER "getBootServer"
}

function getMountPoint
{
	echo -n "What is the mount point of your recovery server?: "; read -r MOUNTPOINT
	if [ ! $MOUNTPOINT ]
		then 
			echo -e "\nNo value set.  Using defaults.\n"
			MOUNTPOINT=/nstation/linux
	fi
}

function listMountPoints
{
	echo -e "\nAvailable mounts on: $BOOTSERVER\n\n"
	LINECOUNT=`/usr/sbin/showmount -e $BOOTSERVER | grep "/linux" | wc -l`
	TEMP=`/usr/sbin/showmount -e $BOOTSERVER | grep "/linux" | tr -s "*" " " | cut -f1 -d" " | tr -s "\n" "\t"`
	TEMPC=1	
	while [ $TEMPC -le $LINECOUNT ]
	do
		MountArray[$TEMPC]=`echo $TEMP | cut -f$TEMPC -d" " | cut -f1 -d" "`
		echo -e "\t $TEMPC. ${MountArray[$TEMPC]}"
		TEMPC=$((TEMPC+1))
	done
	echo -e "\t 0. Quit"
	echo -e "\n"
	echo -n "Choose a mount point: "; read -r SELECT
        if [ -z "$SELECT" ]; then SELECT=x; fi          #Change empty selection to invalid. 
	checkForRange "$SELECT" $((LINECOUNT-0)) "listMountPoints"
	MOUNTPOINT=${MountArray[$SELECT]}
}

function unmountBootServer
{
	echo -n "Unmounting Server..."
	umount $DEFAULT_MOUNTPOINT
	echo -e " Done."
}

function mountBootServer
{
	if [ $MOUNTPOINT ] && [ $BOOTSERVER ]
		then 
			echo -e "\n\n"
			echo  "Mounting $BOOTSERVER:$MOUNTPOINT  Please wait..."
			mkdir -p $DEFAULT_MOUNTPOINT
			# Unmount any left over mounts, before mounting default_mountpoint
			unmountBootServer

			if mount $BOOTSERVER:$MOUNTPOINT $DEFAULT_MOUNTPOINT
				then echo -e " Mount successful."
				else
					echo -e " ERROR: Mount unsuccessful. Check $BOOTSERVER:$MOUNTPOINT:"
					unmountBootServer
			fi

		else
			echo -e "\n\n"
			echo -e "Recovery server and mount point not both specified.\n"
			echo -e "Assuming $IMAGENAME is in file system.\n"
			USINGEXISTINGFS=y

	fi
	if [ -f $SERVERROOT/$IMAGENAME ]
		then
			echo -e "Image found.\n"
		else
			echo -e "Image not present or not accessible.\n"
	fi
	echo -e "\n"
}

# Is an IDF file for this hardware type?
function idf_ok_for_hardware {
  File=$1
  if [ "$MODEL_TYPE" = "N70" -o "$MODEL_TYPE" = "N50" -o "$MODEL_TYPE" = "BIOS" ]; then
    if  grep "HEAD" $File | grep "HARDWARE=N70" > /dev/null ; then
      return 0
    fi     
  elif [ "$MODEL_TYPE" = "2200" -o "$MODEL_TYPE" = "2800" ]; then
    if grep "HEAD" $File | grep "HARDWARE=2x00" > /dev/null ; then
      return 0
    fi     
  else
    # unknown model. assume IDF is ok.
    return 0
  fi
  # check that a HARDWARE tag is present, just that it was not correct.
  if  grep "HEAD" $File | grep "HARDWARE=" > /dev/null ; then
    return 1
  else
    # no Hardware tag. assume IDF is ok.
    return 0
  fi     
}

function idf_fits_on_flash_card {
        # Get the flash size if not already known
        if [ -z $flash_size ]; then
                flash_size=`/IBM/bin/e2fs_flash_info.sh | grep total_useable_bytes | cut -d= -f2`
                if [ -z $flash_size ]; then
                        # Can't get the flash size - assume IDF is ok
                        return 0
                fi
        fi

        # Get the compressed size from the HEAD line in the IDF
        idf_size=`awk '{ if( match( $1, /^[Hh][Ee][Aa][Dd]/ )) { for( i=2; i<=NF; i++ ) { if ( match( $i, /^[Cc][Oo][Mm][Pp][Rr][Ee][Ss][Ss][Ee][Dd][Ss][Ii][Zz][Ee]=/ )) { print substr( $i, 16 ) ; exit }} ; exit }}' $1`

	if [ `expr $idf_size \< $flash_size` = "1" ]; then
                # IDF is ok
                return 0 
        fi

        # IDF is too big
        return 1
}

function listFlashImages
{
        # add check for existance of some idf files  ???


    	if [ "$USINGEXISTINGFS" != "y" ] ; then
		IDF_DIR=$DEFAULT_MOUNTPOINT$DEFAULT_IMAGE_DIR
		echo -e "\nAvailable Flash Images on: $BOOTSERVER:$MOUNTPOINT\n\n"
	else
		IDF_DIR=$DEFAULT_IMAGE_DIR
		echo -e "\nAvailable Flash Images in: $IDF_DIR\n\n"
	fi

	count=1

	for i in $IDF_DIR/*.idf; do
            # make sure the IDF is ok or probably OK for this hardware
            # type before displaying the IDF.
            if idf_ok_for_hardware $i; then
                # check if the IDF will fit on the flash card
                if idf_fits_on_flash_card $i; then
                        # The IDF fits -- allow it to be selected
                        IDFArray[$count]=$i
                        echo -e "\t $count. `basename ${IDFArray[$count]}`"
                        count=$((count+1))
                else
                        # The IDF doesn't fit -- block it from being selected
                        echo -e ""
                        echo -e "\t`basename $i` is too large for this flash card."
                        echo -e ""
                fi
            fi

	done
	echo -e "\t 0. Quit"
	echo -e "\n"
	echo -n "Choose a Flash Image: "; read -r CHOICE
	if [ -z "$CHOICE" ]; then CHOICE=x; fi        #Change empty selection to invalid
	checkForRange "$CHOICE"  $((count-1)) "listFlashImages"
	IMAGENAME=${IDFArray[$CHOICE]}
	export IMAGENAME
	
}

function checkForFlashReboot
{
        echo -e "\n"
	echo -n "On flash completion, do you want to reboot to Flash ([y]/n) ?: "; read -r input
        case $input in
		""|[yY]|[yY][eE][sS]) 
                   FLASH_REBOOT=y
                   ;;
		[nN]|[nN][oO])
                   FLASH_REBOOT=n
                   ;;
		*)
			echo -e "\nInvalid Response\n"
			checkForFlashReboot;;
	esac


}

function checkForDeltaUpdates
{
        DELTA_UPDATE=n
        echo -e "\n"
	echo -n "Is this a delta update of the flash [n] (y/n) ?: "; read -r input
        case $input in
		[yY]|[yY][eE][sS]) 
                   DELTA_UPDATE=y
                   PARTITION_FLASH=n
                   ;;
		*)
                   ;;
 	esac


}

function checkForPartitionFlash
{
        if [ "$DELTA_UPDATE" = n ]; then 
                echo -e "\n"
                echo "Note: If the flash is not partitioned, it will have errors in subsequent steps"
                echo -n "Do you want to create the flash partition [ y ] : (y/n) ? "; read -r input

                case $input in
                ""|[yY]|[yY][eE][sS]) 
                   PARTITION_FLASH=y
                   ;;
                [nN]|[nN][oO])
                   PARTITION_FLASH=n
                   ;;
		*)
        	   echo -e "\nInvalid Response\n"
		   checkForPartitionFlash;;
                esac
        fi


}

function checkForRange # number upperlimit callingFunction
{
	BADCHOICE=0

        TEST=`echo "$1" | grep '[^0-9]'`

        # Test for non-numeric input        
        if [ "$TEST" ]; then                               
                echo -e "\nInvalid selection. Please enter the number of the selection, or 0 to exit.\n"       
		$3
		return
        fi

	if [ $1 -eq 0 ]
		then
			umount $DEFAULT_MOUNTPOINT
			sync;sync;sync
			exit
	fi

	if [ $1 -lt 1 ]
		then 
			BADCHOICE=1
	fi

	if [ $1 -gt $2 ]
		then
			BADCHOICE=1
	fi

	if [ $BADCHOICE -eq 1 ]
		then
			BADCHOICE=0
			echo -e "\nInvalid value.\n"
			$3
	fi
}

function callFlashInit
{
        if [ x$PARTITION_FLASH = x"y" ]; then
                # Signal to snmp that the flash recovery is about to begin, so that
                # TCM is prevented from interrupting us.
                MACHINESTATE="FlashRecovery"
                export MACHINESTATE
                /etc/rc.d/init.d/snmpd restart notrap
                echo -n "Partitioning Flash... Please Wait. "
                . /IBM/FlashRecovery/cf_flashinit.sh
        else
                echo -n "Mounting Flash... Please Wait. "
                . /IBM/FlashRecovery/cf_umount.sh
                . /IBM/FlashRecovery/cf_mount.sh
        fi
        echo " Done."
}

function updateFlash 
{
        echo -e "\n"
	if [ "$USINGEXISTINGFS" != "y" ] ; then
                file=`echo $1 | cut -c12- `
                M_OPTION="-m $DEFAULT_MOUNTPOINT"
	else
		file=$1
		M_OPTION=
	fi
	
        if [ "$DELTA_UPDATE" = "y" ]; then
                UPDATE_MESSAGE="Updating Compact Flash Image with $1 "
                F_OPTION=
                T_OPTION="-t 200"
        else
                UPDATE_MESSAGE="Creating New Compact Flash Image with $1 "
                F_OPTION="-f"
                T_OPTION="-t 203"
        fi

        if [ "$PROXYURL" ]; then
		P_OPTION=`echo "-p" $PROXYURL`
        else
                P_OPTION=
        fi	

        echo $UPDATE_MESSAGE
        echo "... Please wait. "
        if [ ! -e /var/log/lcma ]; then
                mkdir -p /var/log/lcma
        fi

        rm -rf /tmp/lcma/*

        if [ "$DELTA_UPDATE" = "y" ]; then

                export PATH=${SERVERROOT}/mnt/base/bin:${SERVERROOT}/mnt/base/sbin:$PATH
                export LD_LIBRARY_PATH=${SERVERROOT}/mnt/base/lib:$LD_LIBRARY_PATH

                if [ "$USINGEXISTINGFS" = "y" ] ; then
                        /IBM/bin/baseOSUpdate.sh -u -s $SERVERROOT -c $DOMROOT -r y
                else
                        /IBM/bin/baseOSUpdate.sh -u -s $DEFAULT_MOUNTPOINT -c $DOMROOT -r y
                fi
        else
                if [ "$MODEL_TYPE" = "2200" -o "$MODEL_TYPE" = "2800" ]; then
                        if [ "$USINGEXISTINGFS" = "y" ] ; then
                                /IBM/bin/baseOSUpdate.sh -f -s $SERVERROOT -c $DOMROOT -r n
                        else
                                /IBM/bin/baseOSUpdate.sh -f -s $DEFAULT_MOUNTPOINT -c $DOMROOT -r n
                        fi
                fi

		# CLUDGE to prepare for future software update that adds netscape
		# lcma cannot mkdir of /usr/lib/netscape-4.78 while flash booted during software update
		mkdir -p ${FLASHMOUNT1}/usr/lib/netscape-4.78
        fi

        export DELTA_UPDATE
        export SERVERROOT

        /tmp/lcmaStart $P_OPTION $T_OPTION $F_OPTION -s $file $M_OPTION -r $FLASHMOUNT1 -c $file
}

function check_valid # number callingFunction 
{
	BADVAL=0
        TEMP=`echo $1 | tr -d "[a-z][A-Z][\-\"]"`
        if [ ${#TEMP} -ne ${#1} ]
                then BADVAL=1
        fi

        TEMP=`echo $1 | cut -f1 -d"."`
        if [ $TEMP -gt 255 ]
                then BADVAL=1
        fi
        TEMP=`echo $1 | cut -f2 -d"."`
        if [ $TEMP -gt 255 ]
                then BADVAL=1
        fi
        TEMP=`echo $1 | cut -f3 -d"."`
        if [ $TEMP -gt 255 ]
                then BADVAL=1
        fi
        TEMP=`echo $1 | cut -f4 -d"."`
        if [ $TEMP -gt 255 ]
                then BADVAL=1
        fi

	if [ $BADVAL -eq 1 ]
		then
			BADVAL=0
			echo -e "\nInvalid value\n";
			$2
	fi
} 

function check_memory
{
        # Checks for minimum system memory
        # -- Need at least 64Meg of RAM.  We will do
        # the check against 59000 because we don't know how
        # much of the 64M RAM will be used for video.
        # This is the same check as Setup Utility does.
        memsize=`awk '/MemTotal/{print $2}' /proc/meminfo`
        
        if [ $memsize -lt 59000 ]; then
                if [ ! -e /var/log/lcma ]; then
                        mkdir -p /var/log/lcma
                fi
                echo "ERROR: Update of the flash card not allowed.  Total System Memory less than required 64Meg" | tee /var/log/lcma/client_task.log

                return 101
        fi
}

function cancel_autoupdate
{
        # If running on 2x00, send msg to the progress area (so it can be seen
        # in non-verbose)
       	if [ "$MODEL_TYPE" = "2200" -o "$MODEL_TYPE" = "2800" ]; then
                if [ "$DELTA_UPDATE" = "y" ]; then
                        echo "98 Software Update not allowed. $1" > /proc/progress
		else
			echo "98 Flash Recovery not allowed. $1" > /proc/progress
		fi
	fi

        # Send error trap 
       	if [ "$DELTA_UPDATE" = "y" ]; then
           	/IBM/bin/gentrap 6 4 /IBM/bin/cf_InstallFlashImage 200
       	else
               	/IBM/bin/gentrap 6 4 /IBM/bin/cf_InstallFlashImage 203
       	fi

        sleep 15  # Give the user a chance to read the message and ponder the situation
        exit 101  # Bye      
}

function check_for_automate
{
        if [ "$AUTOUPDATE_ON_SERVER" = "n" -a "$BOOTSOURCE" = "server" ]; then
                . /IBM/FlashRecovery/cf_umount.sh
                . /IBM/FlashRecovery/cf_mount.sh
        fi

        if [ -f $AUTOUPDATE_PATH ]; then
                . $AUTOUPDATE_PATH      
        else
                PROMPTFORSERVER=y
        fi

        if [ "$AUTOUPDATE_ON_SERVER" = "n" -a "$BOOTSOURCE" = "server" ]; then
                . /IBM/FlashRecovery/cf_umount.sh
        fi

        if [ "$PROMPTFORSERVER" != "y" ]; then
                # The autoupdate file was found.
                # Before doing the automated update, check for minimum system memory
                check_memory
                if [ $? -eq 101 ]; then
                        # Not enough memory, cancel the update
                        cancel_autoupdate 'Need 64M of RAM'
                fi

                mountBootServer				

                # Before doing the automated update, check if the idf is the right
                # hardware type for the flash card.
                if ! idf_ok_for_hardware $SERVERROOT/$IMAGENAME; then
                        # IDF is wrong hardware type.  Log an error and cancel the update
                        if [ ! -e /var/log/lcma ]; then
                                mkdir -p /var/log/lcma
                        fi
                        echo "ERROR: Update of the flash card not allowed.  IDF $IMAGENAME has the wrong hardware type for this system." | tee /var/log/lcma/client_task.log
      			unmountBootServer
	                cancel_autoupdate 'Wrong model'
                fi

                # Before doing the automated update, check if the idf will fit
                # flash card.
                if ! idf_fits_on_flash_card $SERVERROOT/$IMAGENAME; then
                        # IDF doesn't fit.  Log an error and cancel the update
                        if [ ! -e /var/log/lcma ]; then
                                mkdir -p /var/log/lcma
                        fi
                        echo "ERROR: Update of the flash card not allowed.  IDF $IMAGENAME is too big to fit on the flash card." | tee /var/log/lcma/client_task.log
      			unmountBootServer
	                cancel_autoupdate 'IDF is too big'
                fi
	else
                # The autoupdate file was not found.
                if [ "$DISABLEPROMPT" = "y" ]; then
                        # The caller told us to cancel in this case.
                        exit 100
                fi

                # Before putting up the prompts, check for minimum memory
                check_memory
                if [ $? -eq 101 ]; then
                        echo "Press <Enter> to cancel the update "
                        read -r input
                        exit 101
                fi

		if [ "$BOOTSOURCE" = "flash" ]; then
                        # Boot source is flash, autoupdate file was not found
                        # Set up to show prompts for boot server, mount, and IDFs
                        USINGEXISTINGFS=n
		else
                        # Boot source is server
                        if [ "$AUTOUPDATE_ON_SERVER" = "y" ]; then
                                # autoupdate was supposed to be on server
                                # Assume we're doing a flash recovery.  Default
                                # the settings so that only the IDF selection prompt appears
                                USINGEXISTINGFS=y
                                DELTA_UPDATE=n
                                PARTITION_FLASH=y
                                FLASH_REBOOT=y
                                CONFIRM_REBOOT=n
                        else
                                # autoupdate was supposed to be on flash
                                # Prompt to use this boot server as update server, or another server
                                # (sets USINGEXISTINGFS)
                                chooseLocalRemote
                                # Force writing of autoupdate file to this boot server
                                AUTOUPDATE_ON_SERVER=y
                        fi
		fi

                # If not using the current boot server, then prompt for the server mount.
                if [ "$USINGEXISTINGFS" != "y" ]; then
                        if [ ! $BOOTSERVER ]; then 
                                getBootServer
                        fi
                        if [ ! $MOUNTPOINT ]; then
                                listMountPoints
                        fi
                        mountBootServer
                fi

                # Show available IDFs
                listFlashImages

		if [ "$AUTOUPDATE_ON_SERVER" = "n" -o "$BOOTSOURCE" = "flash" ]; then
                        checkForDeltaUpdates
                        checkForPartitionFlash
                        checkForFlashReboot
		fi

		# If the user selected flash recovery, and we're flash booted,
		# then we need to set the box to server booted.
		if [ "$DELTA_UPDATE" = "n" -a "$BOOTSOURCE" = "flash" ]; then
			echo -e "\nNOTE:  This client is flash booted, and a flash recovery\n (delta update = no) was selected."
			echo -e "This client will be server booted to $BOOTSERVER/$MOUNTPOINT \nto do the recovery."
			echo -e "Do you wish to continue? ([y] n)"
			read -r SELECT
			if [ -n "$SELECT" -a "$SELECT" != "y" ]; then
				exit
			fi 
			if [ "$MODEL_TYPE" = "2200" -o "$MODEL_TYPE" = "2800" ]; then
				/IBM/bin/writeNvram 80 "nfs://$BOOTSERVER/$MOUNTPOINT/kernel.2x00"
			else
				/IBM/bin/writeNvram 80 "nfs://$BOOTSERVER/$MOUNTPOINT"
			fi
			/IBM/bin/writeNvram 85 server
		fi

                SAVE_AUTOUPDATE=y
	fi			
}

function flashReboot
{
   echo "Set for Flash Reboot"

   # Uncomment next 2 lines for debug
   # echo "For debug - type exit to continue "
   # /bin/sh

   #  Check for error in building flash - if error, do not reboot ??? 

   # Set the boot mode to flash boot.
#   if [ "$MODEL_TYPE" = "2200" -o "$MODEL_TYPE" = "2800" ]; then
#        /IBM/bin/writeNvram 80 "nfs://0.0.0.0/kernel.2x00"
#        /IBM/bin/writeNvram 81 nil 
#   fi     
              
   /IBM/bin/writeNvram 85 local    

   cd /IBM/FlashRecovery
   umount $FLASHMOUNT1
   umount $FLASHMOUNT2 
   sync;sync;sync

   # Reboot - forced w/o user confirmation
   if [ "$CONFIRM_REBOOT" = "y" ]; then
      echo -e "\n"
      echo -n "NVRAM changed to do flash reboot - Continue with reboot [y] : (y/n) ? "; read -r input
      if [ $input ]; then
        if [ x$input == x"y" ]; then
                # echo -e "/IBM/bin/reboot_IBM_NS   5\n"
                /IBM/bin/reboot_IBM_NS   5
        fi
      else
        /IBM/bin/reboot_IBM_NS   5
      fi
   else
   	# echo -e "/IBM/bin/reboot_IBM_NS   5\n"   
        /IBM/bin/reboot_IBM_NS   5
   fi
}


#------------------------
# Start Main section 
#------------------------

# Set the env vars needed by this script and called scripts
. /etc/rc.d/rc.IBM_NS.env

# parse the kernel command line
`awk -f/bin/cmdline_export_awk /proc/cmdline`
if [ "$AAAAroot" ]; then   
	export root=$AAAAroot

fi

if [ "$MODEL_TYPE" = "N70" -o "$MODEL_TYPE" = "N50" -o "$MODEL_TYPE" = "BIOS" ]; then
	if [ "$BOOTSOURCE" = "flash" ]; then
 	       	FLASHMOUNT1=/mnt/serverhost             # Mount to apps partition on flash
        	FLASHMOUNT2=/nstation                   # Mount to nstation partition on flash
	else
 	     	FLASHMOUNT1=/mnt/serverhost/mnt/hd1     # Mount to apps partition on flash
        	FLASHMOUNT2=/mnt/serverhost/mnt/hd2     # Mount to nstation partition on flash
	fi
        CONFIGSMOUNT=/configs                   # Directory for autoupdate file stored locally
        DOMROOT=/                               # Root directory of the DOM
        SERVERROOT=/mnt/serverhost              # Root directory of the apps
	DEFAULT_MOUNTPOINT=$SERVERROOT/mnt/update
else
	if [ "$BOOTSOURCE" = "flash" ]; then
 	       	FLASHMOUNT1=/                           # Mount to apps partition on flash
        	FLASHMOUNT2=/nstation                   # Mount to nstation partition on flash
	else
        	FLASHMOUNT1=/mnt/hd1
        	FLASHMOUNT2=/mnt/hd2
	fi
        CONFIGSMOUNT=$FLASHMOUNT2/configs
        DOMROOT=$FLASHMOUNT1
        SERVERROOT=/
	DEFAULT_MOUNTPOINT=/mnt/update
fi

# Figure out where to look for the autoupdate file
if [ "$1" = "--softwareupdate" ]; then
        # Look on the flash card
	AUTOUPDATE_ON_SERVER=n
	AUTOUPDATE_PATH=$CONFIGSMOUNT/autoupdate
else
        # Look on the server
	AUTOUPDATE_ON_SERVER=y
	AUTOUPDATE_PATH=$SERVERROOT/IBM/FlashRecovery/autoupdate
fi

DISABLEPROMPT=n
if [ $# = 2 ] && [ "$2" = "--noprompt" ]; then
        # Caller wants us to exit if autoupdate is not found
        DISABLEPROMPT=y
fi

#set-up defaults
FLASH_REBOOT=n
CONFIRM_REBOOT=n
SAVE_AUTOUPDATE=n

#mkdir -p $FLASHMOUNT1
#mkdir -p $FLASHMOUNT2

#definitions for standard mount directory and images directory
DEFAULT_IMAGE_DIR=/IBM/update/idf

# -- Start

# /usr/bin/clear
echo -e "\nWelcome to IBM NetVista Flash Recovery Tool v1.0\n\n"

# Need this to fake out lcma (copies all files to $FLASHMOUNT1)
#if [ "$BOOTSOURCE" == "flash" ]; then 
#        ln -sf $SERVERROOT $FLASHMOUNT1
#        if [ "$MODEL_TYPE" = "N70" -o "$MODEL_TYPE" = "N50" -o "$MODEL_TYPE" = "BIOS" ]; then
#                mount -n /dev/hdd2 $FLASHMOUNT1/nstation
#        else
#                mount -n /dev/hda2 $FLASHMOUNT1/nstation
#        fi
#fi

# Get inputs, if "autoupdate" file is not present
check_for_automate

# Partition/initialize Flash, if specified and mount /dev/hda1 and /dev/hda2
if [ "$BOOTSOURCE" != "flash" ]; then
        callFlashInit
fi

if [ "$SAVE_AUTOUPDATE" = "y" ]; then
        # We will only write the autoupdate file and then reboot
        # so the the update can happen in "minimal" mode
        # on the next boot(before X starts).
        # Otherwise, we may run out of memory.
        AUTOUPDATE_PATH=$CONFIGSMOUNT/autoupdate
        echo "BOOTSERVER=$BOOTSERVER" > $AUTOUPDATE_PATH
        echo "MOUNTPOINT=$MOUNTPOINT" >> $AUTOUPDATE_PATH
       	if [ "$MODEL_TYPE" = "2200" -o "$MODEL_TYPE" = "2800" ]; then
        	echo "IMAGENAME=$IMAGENAME" >> $AUTOUPDATE_PATH
	else
        	echo "IMAGENAME=${IMAGENAME#$SERVERROOT}" >> $AUTOUPDATE_PATH
		
	fi
        echo "DELTA_UPDATE=$DELTA_UPDATE" >> $AUTOUPDATE_PATH
        echo "PARTITION_FLASH=$PARTITION_FLASH" >> $AUTOUPDATE_PATH
        echo "FLASH_REBOOT=$FLASH_REBOOT" >> $AUTOUPDATE_PATH
        echo "CONFIRM_REBOOT=$CONFIRM_REBOOT" >> $AUTOUPDATE_PATH

        /IBM/bin/writeNvram 78 1

        sync
        sync
        echo "Press <Enter> to reboot and update the flash card: "
        read -r input

        /IBM/bin/reboot_IBM_NS 5
        sleep 30
        exit
else
        # Update flash - calls lcma  
        updateFlash $IMAGENAME
fi


if [ $BOOTSOURCE != "flash" ]; then
   # create lcma log directory
   mkdir $FLASHMOUNT2/lcma
fi

#Unmount server on default_mountpoint
unmountBootServer

# Reboot from flash if so requested
if [ "$FLASH_REBOOT" = "y" ]; then
    flashReboot
fi

# If we get here ... (didn't reboot above)
# Signal to snmp that the update is done.
MACHINESTATE="Running"
export MACHINESTATE
/etc/rc.d/init.d/snmpd restart notrap
