#!/bin/bash
#set -x

if [ "$MODEL_TYPE" != "BIOS" ]; then

# Perform the sfdisk command to garner disk information
if [ "$MODEL_TYPE" = "2200" -o "$MODEL_TYPE" = "2800" ]; then
	SFDISKOUT=`/sbin/sfdisk -g /dev/hda`
else
	SFDISKOUT=`/sbin/sfdisk -g /dev/hdd`
fi

# Pull the pieces of information we need and store them in variables
typeset -i CYLINDERS=`echo $SFDISKOUT | cut -f2 -d" "`
typeset -i HEADS=`echo $SFDISKOUT | cut -f4 -d" "`
typeset -i SECTORS=`echo $SFDISKOUT | cut -f6 -d" "`
typeset -i TOTAL_SIZE=$CYLINDERS*$HEADS*$SECTORS

typeset -i CYL_SIZE_BYTES=`/IBM/bin/e2fs_flash_info.sh | grep cylinder_size_bytes | cut -d= -f2`

# Set the size of each fixed partition in cylinders

# Figure out the size of the nstation partition, in bytes
typeset -i SECOND_PART_SIZE_BLOCKS=`/IBM/bin/e2fs_flash_info.sh | grep blocks_in_second_partition | cut -d= -f2`
typeset -i NSTATION_PART_SIZE_BYTES=$SECOND_PART_SIZE_BLOCKS*1024

# Set the size of the /nstation partition, in cylinders
typeset -i NSTATION_PART_SIZE_CYLS=`expr $NSTATION_PART_SIZE_BYTES \/ $CYL_SIZE_BYTES`

# Set the size of each partition in sectors
typeset -i PART2_CYLINDERS=$CYLINDERS-$NSTATION_PART_SIZE_CYLS
typeset -i PART2_START=$PART2_CYLINDERS*$HEADS*$SECTORS
typeset -i PART2_SIZE=$TOTAL_SIZE-$PART2_START
typeset -i PART1_START=$SECTORS
typeset -i PART1_SIZE=$PART2_START-$PART1_START

if [ "$MODEL_TYPE" = "2200" -o "$MODEL_TYPE" = "2800" ]; then
        # 2x00
        echo "# partition table of /dev/hda" > partition.out
        echo "unit: sectors" >> partition.out
        echo "" >> partition.out
        echo "/dev/hda1 : start= $PART1_START, size= $PART1_SIZE, Id=83" >> partition.out
        echo "/dev/hda2 : start= $PART2_START, size= $PART2_SIZE, Id=83" >> partition.out

        # Do the actual partition
        /sbin/sfdisk --force /dev/hda < partition.out
else
        # N70, N50, BIOS
        echo "# partition table of /dev/hdd" > /tmp/partition.out
        echo "unit: sectors" >> /tmp/partition.out
        echo "" >> /tmp/partition.out
        echo "/dev/hdd1 : start= $PART1_START, size= $PART1_SIZE, Id=83" >> /tmp/partition.out
        echo "/dev/hdd2 : start= $PART2_START, size= $PART2_SIZE, Id=83" >> /tmp/partition.out

        # Do the actual partition
        /sbin/sfdisk --force /dev/hdd < /tmp/partition.out
fi

fi
