#!/bin/sh
################################################################################
# Name: createSDFFlashImage.sh
# Purpose: Creates the flash images (tar files) for one SDF.
# Parameters:
# $1 = SDF name (required)
# $2 = Boot directory (required - for example, /nstation/linux)
# $3 = true | false (indicates whether to re-generate the intermediate SDFs
#                     before creating the flash images -- defaults to false)
#
# Notes:
#
# This script is normally called by the IDF-SDF tool to create the flash image tar
# files for an SDF.  This happens when the SDF is saved.
#
# If you need to change an SDF, you should save the SDF in the SDF Creator part
# of the IDF-SDF tool, and not edit the SDF by hand.
#
# However, if you had edited an SDF without using the IDF-SDF tool,
# and you are running this script by hand, you should set parameter $3 to true.
#
# Changed 2002.02.21 by Peter Van Wazer /tmp/... changed to /tempSDF/...
# so that temp files will no fill up the /tmp ram disk. /tempSDF is on server.
################################################################################


function makeTar
{
        rm -rf ${BOOT_DIR}/tempSDF/image/*
        awk -F'[ =]' -f${BOOT_DIR}/IBM/bin/copy_sdf_files_awk -v srcdir=$BOOT_DIR -v destdir=${BOOT_DIR}/tempSDF/image $1.sdf
        curdir=`pwd`
  cd ${BOOT_DIR}/tempSDF/image
        tar -czf $1.tgz *
 	cd $curdir
}


# Start of main code
sdf=$1
BOOT_DIR=$2
mkdir -p ${BOOT_DIR}/tempSDF/image

# Make sure we can find our libs.
export LD_LIBRARY_PATH=/usr/local/lib:$LD_LIBRARY_PATH

if [ $# -eq 3 ] && [ "$3" = "true" ]; then
        chroot $BOOT_DIR /opt/IBMJava2-13/jre/bin/java -cp /IBM/update/LCMT.jar UpdateIDF /IBM/update/idf /IBM/update/sdf
fi

export sdf_dir=${sdf%.sdf}

ls ${sdf_dir}/*.sdf | {

	while read __sdf; do
		__sdf_name=`echo ${__sdf} | sed -e "s/\.sdf$//" `
		makeTar ${__sdf_name}
	done
}

rm -rf ${BOOT_DIR}/tempSDF



