#!/bin/sh

##
# Create the uncompressed portion of the Image Description File (IDF)
# in the /tmp directory to be evaluated by the IDFBuilder java application
# for an accurate flash-card ext2 filesystem disk usage measurement.
#
# @param $1 (required) base directory to find the /IBM/update/idf directory.
# @param $2 (required) IDF path and file name relative to the base directory.
# @param $3 (optional) "-v" which turns on verbose messaging.
#
# @returns string fully-qualified path of the uncompressed directory
#  for the IDFBuilder java application to parse and get correct disk usage
#  measurements.
##

boot_dir=$1
idf=$boot_dir/$2

if [ "$3" = "-v" ] ; then
  verbose="true"
fi

flash_block_size=1024

uncompressed_tar_list=other.tgz    

base_dirs="base base/sbin base/bin base/lib"
etc_dirs="etc etc/bootstrap.d"
image_dirs="image image/base image/idf image/sdf"
local_dirs="local local/bin"
localhome_dirs="localhome"
lostfound_dirs="lf1 lf2 lf3 lf4 lf5 lf6 lf7 lf8 lf9 lf10 lf11 lf12 "
mnt_dirs="mnt mnt/hd1 mnt/hd2 mnt/update"
nstation_dirs="nstation nstation/home nstation/linux nstation/machines nstation/profiles"
proc_dirs="proc"
tmp_dirs="tmp"
usr_dirs="usr/bin usr/lib usr/local usr/sbin usr/share usr/X11R6"

uncompressed_dir_list="$base_dirs $etc_dirs $image_dirs $local_dirs $localhome_dirs $lostfound_dirs $mnt_dirs $nstation_dirs $proc_dirs $tmp_dirs $usr_dirs"
         
tmp_dir=/tmp/__`basename $idf`__
uncompressed_base_dir=$tmp_dir/uncompressed
mkdir -p $uncompressed_base_dir

if [ -n "$verbose" ] ; then
  echo boot_dir=$boot_dir
  echo idf=$idf
  echo uncompressed_base_dir=$uncompressed_base_dir
  echo uncompressed_dir_list=$uncompressed_dir_list
fi

for dir in $uncompressed_dir_list ; do
 
   uncompressed_dir=$uncompressed_base_dir/$dir
   if [ -n "$verbose" ] ; then
     echo "mkdir -p $uncompressed_dir"
   fi
   mkdir -p $uncompressed_dir

done


cd $uncompressed_base_dir

cp $boot_dir/IBM/update/sdf/NetVista_BaseOS.sdf $uncompressed_base_dir/image/base

# Since the sizes of both crc.2x00 and crc.n70 are within one byte of each
# other, pick one to use as the placeholder for determining the idf size.
cp $boot_dir/IBM/update/base/crc.2x00 $uncompressed_base_dir/image/base/crc
 
cp $idf $uncompressed_base_dir/image/idf/

for tar in $uncompressed_tar_list ; do
   
   if [ -n "$verbose" ] ; then
     echo tar=$tar
   fi

   for sdf in `cat $idf | sed -e "s/SDF.*SRC=//" -e "/^HEAD/d" | cut -d' ' -f1`; do

     fully_qualified_sdf=$boot_dir/$sdf
     cp $fully_qualified_sdf $uncompressed_base_dir/image/sdf/
 
     sdfdir=`echo $sdf | sed -e "s/\.sdf$//"`

     sdf_tar=$boot_dir/$sdfdir/$tar
     if [ -n "$verbose" ] ; then
       echo sdf_tar=$sdf_tar
       if [ -e $sdf_tar ] ; then 
         echo " " $sdf_tar EXISTS.
       else
         echo "  " $sdf_tar does not exist.
       fi
     fi
     
     # Note that files could be overwritten.  No way to currently account for that.
     tar xzf $sdf_tar >/dev/null 2>&1
   done

done

echo $uncompressed_base_dir


