#!/bin/sh

if [ -f /IBM/bin/profile.functions ]; then
   . /IBM/bin/profile.functions
elif [ -f IBM/bin/profile.functions ]; then
   . IBM/bin/profile.functions
elif [ -f ./profile.functions ]; then
   . ./profile.functions
fi


debug_echo() {

   if [ "$DEBUG" = "true" ]; then
      echo $* >&2
   fi
}

display_help () {

   echo
   echo "Syntax: `basename $0` [options...] <profile> \"<name>\" [\"<description>\"]"
   echo "<profile>	Profile component as listed in the master manifest file"
   echo "<name>		Name for this profile component configuration"
   echo "<description>	Description for this profile component configuration"
   echo "Options:"
   echo " -b/--base <dir>	Base directory for profile input"
   echo " -h/-?/--help		This help text"
   echo " -m/--manifest	<file>	Use alternate manifest file"
   echo " -o/--ouput <dir>	Base directory for profile output"
   echo " -x/--exclude \"<list>\" Files to exclude from the profile"
   echo

   exit 1
}

parse_options () {

   HELP=false
   DEBUG=false
   PROFILE_BASE=/tmp/profile
   OUTPUT_BASE=/tmp/profile/generated
   MANIFEST_FILE=/tmp/profile/machine/manifest.properties
   EXCLUDE_LIST=
   PROFILE_TYPE=
   PROFILE_NAME=
   PROFILE_DESC=

   while [ -n "$1" ]; do

      case $1 in
         "-b"|"--base"):
            shift
            if [ -n "$1" ]; then
               PROFILE_BASE=$1
            fi
            ;;
         "--debug"):
            DEBUG=true
            ;;
         "-h"|"-?"|"--help"):
            HELP=true
            ;;
         "-m"|"--manifest"):
            shift
            if [ -n "$1" ]; then
               MANIFEST_FILE=$1
            fi
            ;;
         "-o"|"--output"):
            shift
            if [ -n "$1" ]; then
               OUTPUT_BASE=$1
            fi
            ;;
         "-x"|"--exclude"):
            shift
            if [ -n "$1" ]; then
               EXCLUDE_LIST="-x $1"
            fi
            ;;
         *):
            PROFILE_TYPE=$1
            shift
            if [ -n "$1" ]; then
               PROFILE_NAME=`echo $1 | sed s/\"/\\\\\\\\\"/g`
               shift
               PROFILE_DESC=`echo $1 | sed s/\"/\\\\\\\\\"/g`
            fi

            break               
            ;;
      esac

      shift
   done

   if [ -z "$PROFILE_TYPE" ]; then
      echo "No profile type specified"
      HELP=true
   fi
   if [ -z "$PROFILE_NAME" ]; then
      echo "No profile name specified"
      HELP=true
   fi

   if [ "$HELP" = "true" ]; then
      display_help
   fi

   debug_echo "PROFILE_BASE=$PROFILE_BASE"
   debug_echo "OUTPUT_BASE=$OUTPUT_BASE"
   debug_echo "MANIFEST_FILE=$MANIFEST_FILE"
   debug_echo "EXCLUDE_LIST=$EXCLUDE_LIST"
   debug_echo "PROFILE_TYPE=$PROFILE_TYPE"
   debug_echo "PROFILE_NAME=$PROFILE_NAME"
   debug_echo "PROFILE_DESC=$PROFILE_DESC"
   debug_echo
}

component_manifest() {

   echo "DisplayableName=\"$PROFILE_NAME\" Description=\"$PROFILE_DESC\" Version=\"`client_version`\" Date=\"`date`\" ComponentType=\"$PROFILE_TYPE\""
}

create_profile () {

   cd $PROFILE_BASE

   mkdir -p $OUTPUT_BASE/$ComponentDirectory
   OUTPUT_FILE=`mktemp -q $OUTPUT_BASE/$ComponentDirectory/$PROFILE_TYPE.XXXXXX`
   if [ $? -ne 0 ]; then
      echo "$0: Can not create temp file, exiting..."
      exit 1
   fi

   debug_echo `component_manifest`

   # Create the profile manifest file
   mkdir -p $OUTPUT_FILE.dir
   component_manifest > $OUTPUT_FILE.dir/manifest

   # Zip the profile
   zip -jq $OUTPUT_FILE.zip $OUTPUT_FILE.dir/manifest
   component_manifest | zip -qz $OUTPUT_FILE.zip
   for file in `echo $Files`; do
      if [ "$file" = "home/.ICAClient" ]; then
         file="home/.ICAClient/*"
      fi
      __include_list="$__include_list $Type/$file"
   done

   for file in `echo $EXCLUDE_LIST`; do
      __exclude_list="$__exclude_list $Type/$file"
   done

   if [ -n "$__exclude_list" ]; then
      zip -qr $OUTPUT_FILE.zip $__include_list -x $__exclude_list
   else
      zip -qr $OUTPUT_FILE.zip $__include_list
   fi
   # Cleanup.
   rm -rf $OUTPUT_FILE.dir $OUTPUT_FILE

   echo "$ComponentDirectory/`basename $OUTPUT_FILE.zip`"
}





parse_options "$@"

retrieve_manifest_data $PROFILE_TYPE $MANIFEST_FILE

if [ -z "$Files" ]; then
   echo "Error. No configuration files specified in manifest file ($MANIFEST_FILE) for profile ($PROFILE_TYPE)"
   exit 1
fi

create_profile
