#!/bin/sh

if [ -f /IBM/bin/profile.functions ]; then
   . /IBM/bin/profile.functions
fi


debug_echo() {

   if [ "$DEBUG" = "true" ]; then
      echo $* >&2
   fi
}


display_help () {

   echo
   echo "Syntax: `basename $0` [options...] <profile> <url> [<proxy_server>[:<proxy_port>]]"
   echo "<profile>      Profile name and relative path. ex). user/desktop/DEFAULT.ZIP"
   echo "<url>          URL to export the profile. Specify boot location as boot://"
   echo "<proxy_server> IP address of the proxy server."
   echo "<proxy_port>   Port number of the proxy server."
   echo "Options:"
   echo " -h/-?/--help          This help text"
   echo " -m/--manifest	<file>  Use alternate manifest file"
   echo

   exit 1
}

parse_options () {

   HELP=false
   DEBUG=false
   MANIFEST_FILE=/tmp/profile/machine/manifest.properties
   PROFILE_FILE=
   URL=
   PROXY=

   while [ -n "$1" ]; do

      case $1 in
         "--debug"):
            DEBUG=true
            ;;
         "-h"|"-?"|"--help"):
            HELP=true
            ;;
         "-m"|"--manifest"):
            shift
            if [ -n "$1" ]; then
               MANIFEST_FILE=$1
            else
               HELP=true
            fi
            ;;
         *):
            PROFILE_FILE=$1
            shift
            if [ -n "$1" ]; then
               URL=$1
               shift
               if [ -n "$1" ]; then
                  PROXY=$1
               fi
            else
               HELP=true
            fi

            break               
            ;;
      esac

      shift
   done

   if [ -z "$PROFILE_FILE" ]; then
      echo "No profile file specified"
      HELP=true
   fi

   if [ -z "$URL" ]; then
      echo "No url specified"
      HELP=true
   fi

   debug_echo "MANIFEST_FILE=$MANIFEST_FILE"
   debug_echo "PROFILE_FILE=$PROFILE_FILE"
   debug_echo "URL=$URL"
   debug_echo "PROXY=$PROXY"
   debug_echo

   if [ "$HELP" = "true" ]; then
      display_help
   fi
}


delete_profile () {

   protocol=`echo $URL | cut -d: -f1`
   name_and_path=`echo $URL | sed s/^.*:\\\/\\\///`
   name=`echo $name_and_path | cut -d/ -f1`
   path=`echo $name_and_path | sed s/^[^\\/]*//`
   debug_echo "name_and_path = $name_and_path"
   debug_echo "protocol = $protocol"
   debug_echo "name = $name"
   debug_echo "path = $path"

   case $protocol in
      file):
         debug_echo "rm -f $path/$PROFILE_FILE"
         rm -f $path/$PROFILE_FILE
         ;;

      nfs):
         conditional_umount /tmp/profile/mnt/profiles
         mkdir -p /tmp/profile/mnt/profiles
         if conditional_mount $URL /tmp/profile/mnt/profiles; then
            debug_echo "rm -f /tmp/profile/mnt/profiles/$PROFILE_FILE"
            rm -f /tmp/profile/mnt/profiles/$PROFILE_FILE
            umount /tmp/profile/mnt/profiles
         fi
         ;;

      http|https):
         debug_echo "curl \"$URL/GetProfiles?TCMDeleteProfileComponent=$PROFILE_FILE\" -s > /dev/null 2>&1"
         curl "$URL/GetProfiles?TCMDeleteProfileComponent=$PROFILE_FILE" -s > /dev/null 2>&1
         ;;

      boot):
         conditional_umount /tmp/profile/mnt/profiles
         mkdir -p /tmp/profile/mnt/profiles
         if [ "$BOOTSOURCE" != "flash" ]; then
            URL="nfs://$server`dirname $serverBaseDir`/profiles"
            debug_echo "Delete from boot location $URL"
            conditional_mount $URL /tmp/profile/mnt/profiles
         else
            # Mount the flash device ??? 
            debug_echo "Delete from boot device..."
            mount --bind /nstation/profiles /tmp/profile/mnt/profiles
         fi
         debug_echo "rm -f /tmp/profile/mnt/profiles/$PROFILE_FILE"
         rm -f /tmp/profile/mnt/profiles/$PROFILE_FILE
         conditional_umount /tmp/profile/mnt/profiles
         ;;

      *):
         ;;
   esac

}



parse_options "$@"

delete_profile


