#!/bin/sh

unset SHOW_HELP
unset QUERY

#need to set the lang so that the string compares work for /sbin/sfdisk
LANG=en_US
. /tmp/envvars.sh

if [ "$MODEL_TYPE" = "BIOS" ]; then
   echo "cylinders=980"
   echo "cylinder_size_bytes=65536"
   echo "blocks_in_first_partition=60656"
   echo "blocks_in_second_partition=2048"
   echo "blocks_in_all_partitions=62704"
   echo "num_ext2fs_groups=8"
   echo "inode_blocks=128"
   echo "inode_blocks_per_group=16"
   echo "groups_without_super_block=3"
   echo "total_unavailable_blocks=155"
   echo "total_useable_blocks=60501"
   echo "total_useable_bytes=161953024"
   echo ""
   exit
fi

if [ "$MODEL_TYPE" = "2200" -o "$MODEL_TYPE" = "2800" ]; then
   DEVICE=/dev/hda
else
   DEVICE=/dev/hdd
fi

while getopts ":d:hq" OPTION ; do

   case "$OPTION" in
      d):
         DEVICE=$OPTARG ;;
      q):
         QUERY=true ;;
      ?|h|*):
         SHOW_HELP=true ;;
   esac
   
#   echo "OPTION : $OPTION"
#   echo "OPTARG : $OPTARG"
#   echo "OPTIND : $OPTIND"
#   echo

done

if [ "$SHOW_HELP" = "true" ]; then
   echo
   echo "Syntax: `basename $0` [-q] [-h] [-d DEVICE] "
   echo "  -q         query flash device"
   echo "  -h         show help"
   echo "  -d DEVICE  use DEVICE (default is /dev/hda for 2x00 and /dev/hdd for N70)"
   echo

   exit 1
fi

#echo "QUERY  : $QUERY"
#echo "DEVICE : $DEVICE"


cylinders=`/sbin/sfdisk -l $DEVICE 2>/dev/null | grep Disk | cut -d' ' -f3`
if [ -z "$cylinders" ]; then
   exit 1
else
   echo "cylinders=$cylinders"
   cylinder_size_bytes=`/sbin/sfdisk -l $DEVICE | grep Units | cut -d' ' -f5`
   echo "cylinder_size_bytes=${cylinder_size_bytes:=65536}"


   if [ "$QUERY" = "true" ]; then

      BLOCK_ENV=`ls ${DEVICE}? | {
         let count=1
         let blocks_in_all_partitions=0
         while read __device; do
            size=\`/sbin/sfdisk -s $__device\`
            let blocks_in_all_partitions=blocks_in_all_partitions+$size
            case $count in
               1) echo "blocks_in_first_partition=$size" ;;
               2) echo "blocks_in_second_partition=$size" ;;
               3) echo "blocks_in_third_partition=$size" ;;
               4) echo "blocks_in_fourth_partition=$size" ;;
               5) echo "blocks_in_fifth_partition=$size" ;;
               6) echo "blocks_in_sixth_partition=$size" ;;
            esac
            let count=$count+1
         done
         echo "blocks_in_all_partitions=$blocks_in_all_partitions"
      }`
      echo $BLOCK_ENV | tr ' ' '\012'
      export $BLOCK_ENV
      if [ -z "$blocks_in_first_partition" -o "$blocks_in_first_partition" = "0" ]; then
         # This device has not been partitioned.
         unset QUERY
      fi
   fi
   
   if [ "$QUERY" != "true" ]; then

      let blocks_in_all_partitions=`/sbin/sfdisk -s $DEVICE`
      let blocks_in_all_partitions=blocks_in_all_partitions-16
      # The following assumes the 2nd partition will be a fixed size.
      # Assumes 1M on 32M and 48M cards, 2M on 64M or higher cards.  
      if [ $blocks_in_all_partitions -gt 60000 ]; then
        blocks_in_second_partition=2048
      else
        blocks_in_second_partition=1024
      fi
      let blocks_in_first_partition=${blocks_in_all_partitions}-${blocks_in_second_partition}
      echo "blocks_in_first_partition=$blocks_in_first_partition"
      echo "blocks_in_second_partition=$blocks_in_second_partition"
      echo "blocks_in_all_partitions=$blocks_in_all_partitions"

   fi


   num_ext2fs_groups=`expr $blocks_in_first_partition \/ 8192`
   if [ `expr $blocks_in_first_partition % 8192` -ne "0" ]; then
      num_ext2fs_groups=`expr $num_ext2fs_groups + 1`
   fi
   echo "num_ext2fs_groups=$num_ext2fs_groups"

   inode_blocks=128
   echo "inode_blocks=$inode_blocks"

   inode_blocks_per_group=`expr $inode_blocks \/ $num_ext2fs_groups`
   if [ `expr $inode_blocks % $num_ext2fs_groups` -ne "0" ]; then
      inode_blocks_per_group=`expr $inode_blocks_per_group + 1`
   fi
   echo "inode_blocks_per_group=$inode_blocks_per_group"

   groups_without_super_block=`expr \( $num_ext2fs_groups - 1 \) \/ 2`
   echo "groups_without_super_block=$groups_without_super_block"


   total_unavailable_blocks=`expr 1 + \( 4 + $inode_blocks_per_group \) \* $num_ext2fs_groups - 2 \* $groups_without_super_block`
   echo "total_unavailable_blocks=$total_unavailable_blocks"

   total_useable_blocks=`expr $blocks_in_first_partition - $total_unavailable_blocks`
   echo "total_useable_blocks=$total_useable_blocks"

   total_useable_bytes=`expr $total_useable_blocks \* 1024`
   echo "total_useable_bytes=$total_useable_bytes"
fi

exit 0









