#!/bin/sh

if [ -f /IBM/bin/profile.functions ]; then
   . /IBM/bin/profile.functions
fi


debug_echo() {

   if [ "$DEBUG" = "true" ]; then
      echo $* >&2
   fi
}


display_help () {

   echo
   echo "Syntax: `basename $0` [options...] <filename> <url> [<proxy_server>[:<proxy_port>]]"
   echo "<filename>     Relative profile file path from base profile directory."
   echo "<url>          URL to export the profile. Specify boot location as boot://"
   echo "<proxy_server> IP address of the proxy server."
   echo "<proxy_port>   Port number of the proxy server."
   echo "Options:"
   echo " -d/--directory <dir>  Directory to apply profile"
   echo " -h/-?/--help          This help text"
   echo

   exit 1
}

parse_options () {

   HELP=false
   DEBUG=false

   DIRECTORY=/tmp/profile/tmp
   PROFILE_FILE=
   URL=
   PROXY=

   while [ -n "$1" ]; do

      case $1 in
         "-d"|"--directory"):
            shift
            if [ -n "$1" ]; then
               DIRECTORY=$1
            else
               HELP=true
            fi
            ;;
         "--debug"):
            DEBUG=true
            ;;
         "-h"|"-?"|"--help"):
            HELP=true
            ;;
         *):
            PROFILE_FILE=$1
            shift
            if [ -n "$1" ]; then
               URL=$1
               shift
               if [ -n "$1" ]; then
                  PROXY=$1
               fi
            else
               HELP=true
            fi

            break               
            ;;
      esac

      shift
   done

   if [ -z "$PROFILE_FILE" ]; then
      echo "No profile file specified"
      HELP=true
   fi

   if [ -z "$URL" ]; then
      echo "No url specified"
      HELP=true
   fi

   debug_echo "DIRECTORY=$DIRECTORY"
   debug_echo "URL=$URL"
   debug_echo "PROXY=$PROXY"
   debug_echo "PROFILE_FILE=$PROFILE_FILE"
   debug_echo

   if [ "$HELP" = "true" ]; then
      display_help
   fi

}

retrieve_profiles () {

   if [ -n "$PROXY" ]; then
      curl_proxy_option="-x $PROXY"
   fi

   protocol=`echo $URL | cut -d: -f1`
   server_name_and_path=`echo $URL | sed s/^.*:\\\/\\\///`
   server_name=`echo $server_name_and_path | cut -d/ -f1`
   server_path=`echo $server_name_and_path | sed s/^[^\\/]*//`
   debug_echo "server_name_and_path = $server_name_and_path"
   debug_echo "protocol = $protocol"
   debug_echo "server_name = $server_name"
   debug_echo "server_path = $server_path"

   outputfile="$DIRECTORY/$PROFILE_FILE"
   mkdir -p `dirname $outputfile`

   case $protocol in
      file):
         debug_echo "curl -s $URL/$PROFILE_FILE -o $outputfile"
         curl -s $URL/$PROFILE_FILE -o $outputfile
         ;;

      nfs):
         conditional_umount /tmp/profile/mnt/profiles
         mkdir -p /tmp/profile/mnt/profiles
         if conditional_mount $URL /tmp/profile/mnt/profiles; then
            debug_echo "curl -s file:///tmp/profile/mnt/profiles/$PROFILE_FILE -o $outputfile"
            curl -s file:///tmp/profile/mnt/profiles/$PROFILE_FILE -o $outputfile
            umount /tmp/profile/mnt/profiles
         fi
         ;;

      http|https):
         __tcm_response=`curl -s $curl_proxy_option "$URL/GetProfiles?TCMLocation="`
         if [ -n "$__tcm_response" ]; then
            eval export $__tcm_response
            unset __tcm_response

            debug_echo "curl -s $curl_proxy_option $TCMPROFILES/$PROFILE_FILE -o $outputfile"
            curl -s $curl_proxy_option $TCMPROFILES/$PROFILE_FILE -o $outputfile
         fi
         ;;

      boot):
         conditional_umount /tmp/profile/mnt/profiles
         mkdir -p /tmp/profile/mnt/profiles
         if [ "$BOOTSOURCE" != "flash" ]; then
            URL="nfs://$server`dirname $serverBaseDir`/profiles"
            debug_echo "Get from boot location $URL"
            conditional_mount $URL /tmp/profile/mnt/profiles
         else
            # Mount the flash device ???
            debug_echo "Get from boot device..."
            mount --bind /nstation/profiles /tmp/profile/mnt/profiles
         fi
         debug_echo "curl -s file:///tmp/profile/mnt/profiles/$PROFILE_FILE -o $outputfile"
         curl -s file:///tmp/profile/mnt/profiles/$PROFILE_FILE -o $outputfile

         umount /tmp/profile/mnt/profiles

         ;;

      *):
         ;;
   esac


   debug_echo "Unziping $outputfile into $DIRECTORY"
   if ! su $USER -p -c "unzip -q -d $DIRECTORY -o $outputfile -x manifest"; then
      su $USER -c "unzip -q -d $DIRECTORY -o $outputfile -x manifest"
   fi

}




parse_options "$@"

retrieve_profiles



