#!/bin/sh
#
# Get the size of the specified sdf in bytes.  Used by the IDFBuilder java 
# application for an accurate flash-card ext2 filesystem disk usage measurement.

# @param $1 (required) base directory to find the /IBM/update/idf directory. e.g. /nstation/linux, /
# @param $2 (required) SDF path and file name relative to the base directory. e.g. /IBM/update/sdf/NetVista_Print.idf
# @param $3 (optional) "-v" which turns on verbose messaging. 
# @return long int total size of the SDF's mkcramfs-compressed and uncompressed parts in bytes.
#

boot_dir=$1
sdf=$boot_dir/$2

if [ "$3" = "-v" ] ; then
  verbose="true"
fi

tmp_dir=$boot_dir/tmp/__`basename $sdf`__
cram_file=$tmp_dir/`basename $sdf`.cramfs
compressed_dir=$tmp_dir/compressed
uncompressed_dir=$tmp_dir/uncompressed

if [ -n "$verbose" ] ; then
  echo boot_dir=$boot_dir
  echo sdf=$sdf
  echo tmp_dir=$tmp_dir
  echo cram_file=$cram_file
  echo compressed_dir=$compressed_dir
  echo uncompressed_dir=$uncompressed_dir
fi

mkdir -p $tmp_dir
mkdir -p $compressed_dir
mkdir -p $uncompressed_dir

# Calculate the cramfs size for the sdf.
sdfdir=`echo $sdf | sed -e "s/\.sdf$//"`

cd $compressed_dir
for tar in `ls $sdfdir/*.tgz`; do
  if [ "`basename $tar`" != "other.tgz" ]; then

    if [ -n "$verbose" ] ; then
      echo "(compressed) tar=$tar"
    fi

    tar xzf $tar >/dev/null 2>&1
  fi
done

/sbin/mkcramfs $compressed_dir $cram_file > /dev/null
compressedsize=`du -b $cram_file | cut -f1`
rm -rf $cram_file

cd $uncompressed_dir
if [ -f $sdfdir/other.tgz ]; then

  if [ -n "$verbose" ] ; then
    echo "(uncompressed) $sdfdir/other.tgz exists" 
  fi

  tar xzf $sdfdir/other.tgz >/dev/null 2>&1
  uncompressedsize=`du -s -b $uncompressed_dir | cut -f1`
else
  if [ -n "$verbose" ] ; then
    echo "(uncompressed) $sdfdir/other.tgz does not exist" 
  fi

  uncompressedsize=0
fi

rm -rf $tmp_dir

let sdfsize=compressedsize+uncompressedsize

if [ -n "$verbose" ] ; then
  echo compressedsize=$compressedsize
  echo uncompressedsize=$uncompressedsize
  echo sdfsize=$sdfsize
fi

echo $sdfsize

