#!/bin/sh

if [ -f /IBM/bin/profile.functions ]; then
   . /IBM/bin/profile.functions
fi


debug_echo() {

   if [ "$DEBUG" = "true" ]; then
      echo $* >&2
   fi
}

display_help () {

   echo
   echo "Syntax: `basename $0` [options...] <profile>|list <url> [<proxy_server>[:<proxy_port>]]"
   echo "<profile>|list	Profile component as listed in the master manifest file, or the keyword \"list\" for all profiles"
   echo "<url>          URL to export the profile. Specify boot location as boot://"
   echo "<proxy_server> IP address of the proxy server."
   echo "<proxy_port>   Port number of the proxy server."
   echo "Options:"
   echo " -h/-?/--help		This help text"
   echo " -m/--manifest	<file>	Use alternate manifest file"
   echo

   exit 1
}

parse_options () {

   HELP=false
   DEBUG=false

   MANIFEST_FILE=/tmp/profile/machine/manifest.properties
   PROFILE_TYPE=
   URL=
   PROXY=


   while [ -n "$1" ]; do

      case $1 in
         "--debug"):
            DEBUG=true
            ;;
         "-h"|"-?"|"--help"):
            HELP=true
            ;;
         "-m"|"--manifest"):
            shift
            if [ -n "$1" ]; then
               MANIFEST_FILE=$1
            fi
            ;;
         *):
            PROFILE_TYPE=$1
            shift
            if [ -n "$1" ]; then
               URL=$1
               shift
               if [ -n "$1" ]; then
                  PROXY=$1
               fi
            else
               HELP=true
            fi

            break               
            ;;
      esac

      shift
   done

   if [ -z "$PROFILE_TYPE" ]; then
      echo "No profile type specified"
      HELP=true
   fi

   if [ -z "$URL" ]; then
      echo "No url specified"
      HELP=true
   fi

   debug_echo "MANIFEST_FILE=$MANIFEST_FILE"
   debug_echo "PROFILE_TYPE=$PROFILE_TYPE"
   debug_echo "URL=$URL"
   debug_echo "PROXY=$PROXY"
   debug_echo

   if [ "$HELP" = "true" ]; then
      display_help
   fi

}

list_from_fs () {

   ComponentDirectory=$1

   EXISTING_PROFILES=`find /tmp/profile/mnt/profiles/$ComponentDirectory -name *.ZIP 2>/dev/null`

   debug_echo "$EXISTING_PROFILES"

   for profile in $EXISTING_PROFILES; do

      debug_echo "/usr/bin/unzip -Z -z $profile -x"
      __profile_comment=`/usr/bin/unzip -Z -z $profile -x`
      if [ -z "$__profile_comment" ]; then
         echo "Error. Bad zip file: $profile"
         continue
      fi

      echo "File=`echo $profile | sed s/^\\\/tmp\\\/profile\\\/mnt\\\/profiles\\\///`"
      echo -e `/usr/bin/unzip -Z -z $profile -x | sed s/[^=]*=\"[^\"]*\"\ /\&\\\\\\\\\n/g`

      echo
   done
}





parse_options "$@"

if [ "$PROFILE_TYPE" != "list" ]; then
   retrieve_manifest_data $PROFILE_TYPE $MANIFEST_FILE

   if [ -z "$ComponentDirectory" ]; then
      echo "Error in manifest file: $MANIFEST_FILE"
      exit 1
   fi
fi

protocol=`echo $URL | cut -d: -f1`
server_name_and_path=`echo $URL | sed s/^.*:\\\/\\\///`
server_name=`echo $server_name_and_path | cut -d/ -f1`
server_path=`echo $server_name_and_path | sed s/^[^\\/]*//`
debug_echo "server_name_and_path = $server_name_and_path"
debug_echo "protocol = $protocol"
debug_echo "server_name = $server_name"
debug_echo "server_path = $server_path"


case $protocol in
   file):
      list_from_fs $ComponentDirectory
      ;;

   nfs):
      conditional_umount /tmp/profile/mnt/profiles
      mkdir -p /tmp/profile/mnt/profiles
      if conditional_mount $URL /tmp/profile/mnt/profiles; then
         if [ "$PROFILE_TYPE" = "list" ]; then
            list_from_fs
         else
            list_from_fs $ComponentDirectory
         fi
         umount /tmp/profile/mnt/profiles
      fi
      ;;

   http|https):
      if [ -n "$PROXY" ]; then
         curl_proxy_option="-x $PROXY"
      fi
      if [ "$PROFILE_TYPE" = "list" ]; then
         debug_echo "curl -s $curl_proxy_option \"$URL/GetProfiles?TCMProfileComponent=List\""
         curl -s $curl_proxy_option "$URL/GetProfiles?TCMProfileComponent=List"
      else
         debug_echo "curl -s $curl_proxy_option \"$URL/GetProfiles?TCMProfileComponent=$ComponentDirectory\""
         curl -s $curl_proxy_option "$URL/GetProfiles?TCMProfileComponent=$ComponentDirectory"
      fi
      ;;

   boot):
      conditional_umount /tmp/profile/mnt/profiles
      mkdir -p /tmp/profile/mnt/profiles
      if [ "$BOOTSOURCE" != "flash" ]; then
         URL="nfs://$server`dirname $serverBaseDir`/profiles"
         debug_echo "List from boot location $URL"
         conditional_mount $URL /tmp/profile/mnt/profiles
      else
         # Mount the flash device ???
         debug_echo "List from boot device..."
         mount --bind /nstation/profiles /tmp/profile/mnt/profiles
      fi
      if [ "$PROFILE_TYPE" = "list" ]; then
         list_from_fs 
      else
         list_from_fs $ComponentDirectory
      fi
      conditional_umount /tmp/profile/mnt/profiles
      ;;

   *):
      ;;
esac




