#!/bin/sh
# -------------------------------------------------
# Script to check if 2x00 client needs to update
# boot prom.  Will use /proms directory.
# -------------------------------------------------

# Message pop-up to warn the user
  WARNING="\n\n\t\tATTENTION:\n\n\t\tDO NOT POWER OFF THE WORKSTATION!\n\t\tA firmware update is occurring on this workstation.\n\t\tThe mouse and keyboard will be locked during the update.\n\t\tThe workstation will be rebooted when the update is complete\n\n"

#####################################################################
#  Function:  parseargs()
#  Parse command line arguments
#####################################################################
parseargs() {

  while [ -n "$1" ]; do
    case $1 in
      "-debug"):
        DEBUG=true
        ;;
      *):
        ;;
    esac

    shift
  done

}

reflash_debug () {
  if [ $DEBUG = "true" ]; then
    echo $@
  fi

}

echo_progress () {
   if [ "x$MODEL_TYPE" != "xN70" ]; then
#      echo w > /proc/progress
      echo "$*" > /proc/progress
   fi
}


#####################################################################
#  Function:  outputvalues()
#  Output values if in debug
#####################################################################
outputvalues() {
  
  reflash_debug "******* REFLASH VALUES *************"
  reflash_debug "Current boot prom date:  $currentdate"
  reflash_debug "Current boot prom version:  $currentversion"
  reflash_debug "Current model type:  $currentmodeltype"
  reflash_debug "Current version type:  $currentversiontype"
  reflash_debug "Upgrade boot prom date:  $upgradedate"
  reflash_debug "Upgrade boot prom version:  $upgradeversion"
  reflash_debug "Upgrade model type:  $upgrademodeltype"
  reflash_debug "Upgrade version type:  $upgradeversiontype"
  reflash_debug "************************************"

}

#####################################################################
#  Function:  printwarning()
#  Parse command line arguments
#####################################################################
printwarning() {

  echo -en "\\033[1;31m"
  echo -e "\n\n\t\tUpgrading boot prom from $currentdate."	
  echo -e $WARNING
  echo -en "\\033[1;39m"
  #for progress bar only output one line
  echo_progress "100 DO NOT POWER OFF WORKSTATION. UPGRADING FIRMWARE."

}

#####################################################################

DEBUG=false
parseargs $@

if [ $BOOTSOURCE = "server" -a "x$MODEL_TYPE" != "xN70" ]; then

  #Get the date and version of the current boot prom
  currentdate=`head -c1120 /dev/mem | strings -td | grep 1092 | awk '{printf $3}' | sed s/\[\(\)\]//g | sed s/'\/'/' '/g | awk '{print $NF$1$2}' | sed s/'^[0-6]'/'20&'/ | sed s/'^[789]'/'19&'/`

  currentversion=`head -c1120 /dev/mem | strings -td | grep 1092 | awk '{printf $2}'`

  #Get the date and version for the /proms/flash.2x00 file
  upgradedate=`head -c1120 /proms/flash.$MODEL_TYPE | strings -td | grep 1092 | awk '{printf $3}' | sed s/\[\(\)\]//g | sed s/'\/'/' '/g | awk '{print $NF$1$2}' | sed s/'^[0-6]'/'20&'/ | sed s/'^[789]'/'19&'/`

  upgradeversion=`head -c1120 /proms/flash.$MODEL_TYPE | strings -td | grep 1092 | awk '{printf $2}'`


  upgrademodeltype=`echo $upgradeversion | cut -c1`
  upgradeversiontype=`echo $upgradeversion |cut -c2`
  currentmodeltype=`echo $currentversion | cut -c1`
  currentversiontype=`echo $currentversion |cut -c2`

  outputvalues

  # For now only update if they have a su3 boot prom
  # i.e H# or B# instead of HL and BL
  # Can be revisited if we want automatic updates each time
  # though this scenario is very very unlikely and would
  # be considered an erbjoric task.
  
  # If current firmware image is not SU4 and upgrade version in
  # proms directory is SU4 then reflash boot prom
  echo -e "Checking for necessary boot prom upgrade."

  if [ $currentversiontype != "L" -a $upgradeversiontype = "L" ]; then
    if [ -f /proms/flash.$MODEL_TYPE ]; then
      printwarning

      if /IBM/bin/tcm_reflash_util /proms/flash.$MODEL_TYPE > /dev/null 2>&1; then
        echo -e " Flash completed successfully.  Rebooting."
        echo_progress "100 Upgrade completed successfully.  Rebooting."
        sleep 3
        echo 0 >/tmp/reboot
      else
        echo -e " Flash not updated due to errors."
        exit 2
      fi
    else
      echo "Cannot flash image since /proms/flash.$MODEL_TYPE doesn't exist...  EXITING"
    fi
  else
    echo -e "Firmware upgrade not needed $currentversion."
  fi
fi
 
