#!/bin/sh
#######################################################################
# SYNTAX: tcm_restore_1.3_2.0.sh
#
# PURPOSE: Move, parse (and otherwise "migrate") files in the
# /tmp/tcm/restore sandbox from a 1.3 (SU3) image to a 2.0 (R2) image.
# Files are not to be moved out of the sandbox, as this is done by the
# /IBM/bin/tcm_restore.sh script once all application migration
# scripts (like this one) have been run.
#
#######################################################################


BASEDIR=/tmp/tcm/restore
migrationhome=/IBM/migration/home
migrationservermountdir=`dirname $serverBaseDir`/profiles
profiledir=/nstation/profiles/

if [ ! -d /tmp/migration/home ]; then
  mkdir -p /tmp/migration/home
fi

ln -s $BASEDIR/root/KIOSK $migrationhome/root
ln -s $BASEDIR/etc /IBM/migration/etc

# If coming from SU2 then we need to set up again
if [ -d $BASEDIR/home/KIOSK ]; then
  cp -r $BASEDIR/home/KIOSK/* $BASEDIR/root/KIOSK/
fi

# Some setup is needed to massage SU3 files to R2
if [ ! -d $BASEDIR/root/KIOSK/spool/lpd ] ; then
  mkdir -p $BASEDIR/root/KIOSK/spool/lpd
fi

if [ -d $BASEDIR/root/KIOSK/lpd ] ; then
  cp -Rp $BASEDIR/root/KIOSK/lpd/* $BASEDIR/root/KIOSK/spool/lpd/
fi

# Need to figure out where KIOSK home is.  Using /etc/passwd for this.
KIOSKHOME=`cat /etc/passwd | grep ^KIOSK | cut -d: -f6`

# Move files that will be migrated automatically after migration
# This needs to be done because the migration script cleans out
# the home and etc directories when complete.
mkdir -p /tmp/tcm/restore/emulprivate/home/KIOSK
for file in EmulConnections3270.auth EmulConnections5250.auth \
             IBM3270.auth IBM5250.auth ; do
  if [ -f $BASEDIR/home/KIOSK/$file ]; then
    cp $BASEDIR/home/KIOSK/$file /tmp/tcm/restore/emulprivate/home/KIOSK/
  fi
done

mkdir -p /tmp/tcm/restore/netscapeprivate/home/KIOSK
for file in cookies history.list key3.db secmodule.db \
            cert7.db proxyconf ; do
  if [ -f $BASEDIR/root/KIOSK/.netscape/$file ]; then
    cp $BASEDIR/root/KIOSK/.netscape/$file $BASEDIR/netscapeprivate/home/KIOSK/
  fi
done

# Begin migration of SU4 to R2
. migration.sh -backup_restore


# after conversion need to copy profiles to /nstation/profiles
cp -Rp /tmp/profile/mnt/profiles/* /nstation/profiles

# Also copy back emulator private data so automatically restored
if [ ! -d $BASEDIR/home/KIOSK ]; then
  mkdir -p $BASEDIR/home/KIOSK
fi

if [ ! -d $BASEDIR/$KIOSKHOME ]; then
  mkdir -p $BASEDIR/$KIOSKHOME
fi

cp -Rp /tmp/tcm/restore/emulprivate/home/KIOSK/* $BASEDIR/home/KIOSK/
rm -rf /tmp/tcm/restore/emulprivate
cp -Rp /tmp/tcm/restore/netscapeprivate/home/KIOSK/* $BASEDIR/$KIOSKHOME
rm -rf /tmp/tcm/restore/netscapeprivate

