#!/bin/sh

if [ -f /IBM/bin/profile.functions ]; then
   . /IBM/bin/profile.functions
fi


debug_echo() {

   if [ "$DEBUG" = "true" ]; then
      echo $* >&2
   fi
}

display_help () {

   echo
   echo "Syntax: `basename $0` [options...] <url> [<proxy_server>[:<proxy_port>]]"
   echo "<url>          URL profile location. Specify boot location as boot://"
   echo "<proxy_server> IP address of the proxy server."
   echo "<proxy_port>   Port number of the proxy server."
   echo " -h/-?/--help		This help text"
   echo

   exit 1
}

parse_options () {

   HELP=false
   DEBUG=false

   URL=
   PROXY=


   while [ -n "$1" ]; do

      case $1 in
         "--debug"):
            DEBUG=true
            ;;
         "-h"|"-?"|"--help"):
            HELP=true
            ;;
         *):
            if [ -n "$1" ]; then
               # Make sure the url does not end with a '/'
               URL=`echo "$1" | sed -e "s/\/$//"`
               shift
               if [ -n "$1" ]; then
                  PROXY=$1
               fi
            else
               HELP=true
            fi

            break               
            ;;
      esac

      shift
   done

   if [ -z "$URL" ]; then
      echo "No url specified"
      HELP=true
   fi

   debug_echo "URL=$URL"
   debug_echo "PROXY=$PROXY"
   debug_echo

   if [ "$HELP" = "true" ]; then
      display_help
   fi

}




parse_options "$@"


# Initialize return code to "bad".
return_code=1

protocol=`echo $URL | cut -d: -f1`
server_name_and_path=`echo $URL | sed s/^.*:\\\/\\\///`
server_name=`echo $server_name_and_path | cut -d/ -f1`
server_path=`echo $server_name_and_path | sed s/^[^\\/]*//`
server_path2=`echo $server_name_and_path | sed s/^[^\\/]*//`
debug_echo "server_name_and_path = $server_name_and_path"
debug_echo "protocol = $protocol"
debug_echo "server_name = $server_name"
debug_echo "server_path = $server_path"

if [ "$MODEL_TYPE" = "2800" -o "$MODEL_TYPE" = "2200" ]; then
   __flash_device="/dev/hda2"
else
   __flash_device="/dev/hdd2"
fi

debug_echo "__flash_device = $__flash_device"

case $protocol in
   file):
       return_code=0
      ;;

   nfs):
      if [ "$server_name" = "127.0.0.1" ]; then
         #debug_echo "cat /proc/mounts | grep "/nstation ext2" | cut -d' ' -f1"
         #if [ "`cat /proc/mounts | grep "/nstation ext2" | cut -d' ' -f1`" = "$__flash_device" ]; then
         if [ -d /nstation/profiles ]; then
            return_code=0
         fi
      else
        while [ $return_code = "1" -a $server_path != "/" ]
        do
           debug_echo "/usr/sbin/showmount -e $server_name | cut -d' ' -f1 | grep  \"^$server_path\$\""
           /usr/sbin/showmount -e $server_name | cut -d' ' -f1 | grep "$server_path$" > /dev/null
           return_code=$?
           if [ $return_code = "1" ]; then
              server_path=`echo $server_path | sed -n 's:\\([/[^/]*]*\\)/[^/]*.$:\1:p'`
           fi
        done
# we do not want to do the mount test unless we need to
        if [ $return_code = "0" -a "$server_path" != "$server_path2" ]; then
           debug_echo "Doing mount test"
           conditional_umount /tmp/profile/mnt/profiles
           mkdir -p /tmp/profile/mnt/profiles
           if conditional_mount $URL /tmp/profile/mnt/profiles; then
              return_code=0
              umount /tmp/profile/mnt/profiles
           else
              return_code=1
           fi
        fi
      fi
      ;;

   http|https):
      if [ -n "$PROXY" ]; then
         curl_proxy_option="-x $PROXY"
      fi

      debug_echo "curl curl_proxy_option --connect-timeout 10 \"$URL/GetProfiles?TCMLocation=\" -s >/dev/null"
      curl curl_proxy_option --connect-timeout 10 "$URL/GetProfiles?TCMLocation=" -s > /dev/null
      return_code=$?

      ;;

   boot):
      if [ "$BOOTSOURCE" != "flash" ]; then
         debug_echo "/usr/sbin/showmount -e $server | cut -d' ' -f1 | grep \"^`dirname $serverBaseDir`/profiles\$\""
         /usr/sbin/showmount -e $server | cut -d' ' -f1 | grep "`dirname $serverBaseDir`/profiles$" > /dev/null
         return_code=$?
      else
         #debug_echo "cat /proc/mounts | grep "/nstation ext2" | cut -d' ' -f1"
         #if [ "`cat /proc/mounts | grep "/nstation ext2" | cut -d' ' -f1`" = "$__flash_device" ]; then
         # ENB:
         if [ -d /nstation/profiles ]; then
            return_code=0
         fi
      fi
      ;;

   *):
      ;;
esac

echo $return_code
exit $return_code



