#!/bin/sh
# --------------------------------------------------------------------------------
#
# /etc/rc.d/rc.IBM_NS.login
#
# PURPOSE: Setup login (gdm) configuration and authentication options.
# --------------------------------------------------------------------------------

# Re-initialize the environment in order to work with the current settings.
. /etc/rc.d/rc.IBM_NS.env

SERVERNAME=`host $server | grep -v "not found" | awk '{print $NF}' | sed s/\.$//`
AUTHNAME=${SERVERNAME:-$server}

# Set default values.
AutomaticLoginEnable=true
AllowRoot=true

# Read the authentication configuration.
if [ -f /tmp/profile/machine/IBMSetupAuthentication ]; then
   . /tmp/profile/machine/IBMSetupAuthentication
fi

# Set the default "Welcome" text depending on the authentication type.
if [ "${AuthenticatedLoginType:-0}" = "0" ]; then
   Welcome="Welcome to $AUTHNAME"
elif [ "${AuthenticatedLoginType:-0}" = "1" ]; then
   Welcome="Welcome to $NISDomainName"
elif [ "${AuthenticatedLoginType:-0}" = "2" ]; then
   Welcome="Welcome to $SMBDomainName"
else
   Welcome="Welcome to $AUTHNAME"
fi

# Read the login configuration.
if [ -f /tmp/profile/machine/IBMSetupLogin ]; then
   . /tmp/profile/machine/IBMSetupLogin
fi

# "Local Authentication" is not currently supported on flash/peer boot.
if [ "$BOOTSOURCE" != "server" -a "${AuthenticatedLoginType:-0}" = "0" ]; then
   AutomaticLoginEnable=true
fi



mkdir -p /tmp/etc/gdm

{
   cat /etc/gdm/template.gdm.conf |

   sed 's/^AutomaticLoginEnable=.*/AutomaticLoginEnable='"$AutomaticLoginEnable"'/' |

   sed 's/^AllowRoot=.*/AllowRoot='"$AllowRoot"'/' |

   {
      # Set the "Welcome" value.
      export Welcome
      export TmpWelcome
      TmpWelcome=`printenv Welcome | sed -e s/\\\\\\\/\\\\\\\\\\\\\\\\\\\\\\\/g -e s/\\\//\\\\\\\\\\\\\//g -e s/\ /\(___space___\)/g`

      sed -e s/^Welcome=.*/Welcome=`printenv TmpWelcome`/ -e /^Welcome=/s/\(___space___\)/\ /g

   } |

   {
      # Set the "Logo" value.
      Logo=`ls /tmp/profile/machine/login_logo.* 2>/dev/null`
      Logo=`echo $Logo | cut -d' ' -f1`

      if [ -n "$Logo" ]; then
         TmpLogo=`echo $Logo | sed 's/\//\\\\\\//g'`
         eval sed 's/^Logo=.*/Logo=$TmpLogo/'	
      else
         # close the pipe
         cat
      fi
   } |

   {
      # Set the "BackgroundImage" value. 
      BackgroundImage=`ls /tmp/profile/machine/login_background.* 2>/dev/null`
      BackgroundImage=`echo $BackgroundImage | cut -d' ' -f1`

      if [ -n "$BackgroundImage" ]; then
         TmpBackgroundImage=`echo $BackgroundImage | sed 's/\//\\\\\\//g'`
         sed 's/^BackgroundImage=.*/BackgroundImage='"$TmpBackgroundImage"'/'	
      else
         # close the pipe
         cat
      fi
   }

} > /tmp/etc/gdm/gdm.conf



# Create the KIOSK user's home directory.
if [ "${AutomaticLoginEnable:-true}" = "true" -a "${HomeDirPersistent:-true}" = "true" ]; then 
      
   # Create a persistent home in the machine directory.
   if [ ! -d /tmp/local/KIOSK ]; then
      mkdir -p /tmp/local/KIOSK
      chmod 744 /tmp/local/KIOSK
      chown KIOSK:KIOSK /tmp/local/KIOSK
   fi
   ln -sf /tmp/local/KIOSK /tmp/KIOSK

else

   # Create a non-persistent home directory.
   mkdir -p /tmp/KIOSK
   chmod 744 /tmp/KIOSK
   chown KIOSK:KIOSK /tmp/KIOSK

fi

if [ ! -f /tmp/KIOSK/.bashrc ]; then
   cp -f /etc/skel/.bashrc /tmp/KIOSK/.bashrc
fi
