#!/bin/sh
# --------------------------------------------------------------------------------
#
# /etc/rc.d/rc.sysinit.IBM_NS.boot - called from hardware script once at boot.
# Modified for IBM NetVista clients running Linux
#
# This file is subject to the terms and conditions of the GNU General Public
# License.  See the file "COPYING" in the base directory of this archive
# for more details.
#
# --------------------------------------------------------------------------------


update_progress () {
   if [ "$MODEL_TYPE" = "2800" -o "$MODEL_TYPE" = "2200" ]; then
      echo "$*" > /proc/progress
   else
#      echo "** $1 $2 $3 $4 $5 $6 $7 "
      echo "$*"
   fi
}

if [ ! -d /tmp/snmp ]; then
  mkdir -p /tmp/snmp
fi
/IBM/bin/readNvram 91
VERBOSE=`cat /tmp/snmp/91`
echo VERBOSE=$VERBOSE
if [ "$VERBOSE" = "1" ]; then
   export MESSAGE_TARGET=/dev/console
else
   export MESSAGE_TARGET=/dev/null
fi

# Mount the flash user partition.
if [ "$MODEL_TYPE" = "2800" -o "$MODEL_TYPE" = "2200" ]; then __device="/dev/hda2";
elif [ "$MODEL_TYPE" = "N70" -o "$MODEL_TYPE" = "N50" -o "$MODEL_TYPE" = "BIOS" ]; then __device="/dev/hdd2"; fi

if mount -n -t ext2 -o rw,sync $__device /nstation ; then
   if [ ! -d /nstation/linux ]; then mkdir /nstation/linux ; fi
   if [ "$MODEL_TYPE" = "2800" -o "$MODEL_TYPE" = "2200" ]; then
      mount --bind / /nstation/linux
      if [ "$BOOTSOURCE" = "flash" ]; then
	if [ ! -d /nstation/configs ]; then mkdir /nstation/configs ; fi
      	mount --bind /nstation/configs /configs
      fi
   else
      mount --bind /mnt/serverhost /nstation/linux
   fi
   if [ ! -d /nstation/profiles ]; then mkdir /nstation/profiles ; fi
   if [ ! -d /nstation/machines ]; then mkdir /nstation/machines ; fi
   if [ ! -d /nstation/home ]; then mkdir /nstation/home ; fi
fi
unset __device
cat /proc/mounts > /etc/mtab

# Use the installed ld.so.cache file if available.
if [ ! -d /tmp/etc ]; then mkdir /tmp/etc ; fi
if [ -f /etc/ld.so.cache.install ]; then
   cp /etc/ld.so.cache.install /tmp/etc/ld.so.cache
   chmod 644 /tmp/etc/ld.so.cache
else
   /sbin/ldconfig -C /tmp/etc/ld.so.cache
fi



update_progress "59" "updating env"

# ------------------------------------------------------------------------
# ############## Set-up var directory  ##############
# ------------------------------------------------------------------------

. /etc/rc.d/rc.IBM_NS.env

##############################
##############################
##############################
##############################
##############################
##############################
#
#  Load the machine profiles
#

#echo
#echo "Before profile functions"
#echo
#/bin/sh

# Source the profile functions.
. /IBM/bin/profile.functions

update_progress "60" "loading machine profiles" 

profile_init machine

#echo
#echo "After profile.functions"
#echo
#/bin/sh

#
##############################
##############################
##############################
##############################
##############################
##############################


update_progress "62" "machine specific config"

# Mount machine-specific directory according to profile information
/etc/rc.d/rc.IBM_NS.machine


# add this the rc.IBM_NS.machine ????
if [ "x$BOOTSOURCE" = "flash" ]; then
   mount -f /
   mount -f /proc
fi


# ------------------------------------------------------------------------

# ------------------------------------------------------------------------
# ############## Set-up var directory  ##############
# ------------------------------------------------------------------------
#update_progress "64" "var setup"
#/etc/rc.d/rc.IBM_NS.var
# ------------------------------------------------------------------------

update_progress "70" "snmp trap server"

# The following code replaces the trap servers config file
# with the one that was set by TCM, if needed.
# If a trap server config file was in the profile, then
# that one is used.  Otherwise the TCM one is used.
# This must be after the machine profiles are applied,
# and after rc.IBM_NS.var (creates sym links)
# but before rc.IBM_NS.net (appends TRAPMANAGER4 from DHCP),
# and before snmpd (reads the config file).
if [ ! -e /usr/local/lib/snmp/snmpd.conf ]; then
        # No trap servers config file was in the machine profile
        if [ -e /var/snmp/snmpd.conf ]; then
                # A trap server config file was written by TCM
                # Replace the file with the one written by TCM.
                cp -p /var/snmp/snmpd.conf /usr/local/lib/snmp/snmpd.conf
        fi
fi

# Source functions
. /etc/rc.d/init.d/functions

# Print a banner. ;)
echo -e "\n\t\t\tWelcome to Linux\n"


# ------------------------------------------------------------------------
# ############## Configure network settings  ##############
# ------------------------------------------------------------------------
update_progress "72" "configuring network"

. /etc/rc.d/rc.IBM_NS.env
/etc/rc.d/rc.IBM_NS.netconfig

# ------------------------------------------------------------------------
# ############  Set date, if Timeserver is set  ##############
# ------------------------------------------------------------------------
# need to run time script after netconfig so DNS is set up first...
update_progress "75" "updating time"
/etc/rc.d/rc.IBM_NS.time
# ------------------------------------------------------------------------

# ------------------------------------------------------------------------
# needs to run after time script, since dhclient is run in time script:
. /etc/rc.d/rc.IBM_NS.env
# ------------------------------------------------------------------------

# ------------------------------------------------------------------------
# ############# Make h/w specific decisions  ##############
# ------------------------------------------------------------------------
update_progress "80" "hardware device configuration"
/etc/rc.d/rc.IBM_NS.hardware
# ------------------------------------------------------------------------


# ------------------------------------------------------------------------
# ############  Set up migration  #########
# ------------------------------------------------------------------------

if [ $BOOTSOURCE = "server" ]; then
  echo "** Migration check **"
  update_progress "81" "checking for migration"
  /IBM/bin/migration.sh
fi
# ------------------------------------------------------------------------
# ############  Set up X11  #########
# ------------------------------------------------------------------------
update_progress "82" "x11 configuration"
/etc/rc.d/rc.IBM_NS.x11

# ------------------------------------------------------------------------
# ############  Set up login  #########
# ------------------------------------------------------------------------
update_progress "83" "authentication configuration"
/etc/rc.d/rc.IBM_NS.login

# ------------------------------------------------------------------------
# ############  Set up mount points  #########
# ------------------------------------------------------------------------
update_progress "84" "client mount points"
/etc/rc.d/rc.IBM_NS.mount


update_progress "85" "updating mtab"

# Remount the root filesystem read-write.
# echo "Remounting root filesystem in read-write mode."
# mount -n -o remount,rw /
#echo "Mount complete"

# Clean out /etc.
rm -f /etc/mtab~ /fastboot /fsckoptions
cat /proc/mounts > /etc/mtab

# ------------------------------------------------------------------------
#   Having /var/run/utmp is creating problem during login (mingetty) when utmp is 
#   in MACHINE_DIR and not in BOOT_DIR. The only way it works is to have 
#   MACHINE_DIR /var/run/utmp linked to BOOT_DIR. However, this causes problem 
#   where we would like BOOT_DIR to be READ-ONLY (our goal). 
#   The solution is not to have run/utmp (so far it has not caused problems. 
#   Will need more testing). 
# The commented code is the original code
# ------------------------------------------------------------------------
>/var/run/utmp
# ------------------------------------------------------------------------

# Delete UUCP lock files.

# Delete stale subsystem files.
rm -f /var/lock/subsys/*

if [ -n "x$KERNELD" ]; then
   touch /var/lock/subsys/kerneld
fi

# Delete stale pid files
rm -f /var/run/*.pid

# Delete X locks
rm -f /$TMP_DIR/.X*-lock

# Delete Postgres sockets
rm -f /$TMP_DIR/.s.PGSQL.*

# Initialize the serial ports.
if [ -f /etc/rc.d/rc.serial -a "x$MODEL_TYPE" != "x2200" ]; then
   . /etc/rc.d/rc.serial
fi

# Load modules (for backward compatibility with VARs)
if [ -f /etc/rc.d/rc.modules ]; then
   /etc/rc.d/rc.modules
fi

# Use any system tuning features that user might have installed
if [ -f /etc/rc.d/rc.turbo ]; then
   /etc/rc.d/rc.turbo
fi

# Now that we have all of our basic modules loaded and the kernel going,
# let's dump the syslog ring somewhere so we can find it later
if [ -f /bin/dmesg ]; then
   dmesg > /var/log/dmesg
fi

update_progress "86" "network start"
#if [ -f /etc/rc.d/init.d/network ]; then
#   /etc/rc.d/init.d/network start
#fi  

update_progress "88" "portmap start"
if [ -f /etc/rc.d/init.d/portmap ]; then
   /etc/rc.d/init.d/portmap start
fi

update_progress "90" "syslog start"
if [ -f /etc/rc.d/init.d/syslog ]; then
   /etc/rc.d/init.d/syslog start
fi

update_progress "92" "snmpd start"
if [ -f /etc/rc.d/init.d/snmpd ]; then
   # Indicate to snmp that no-one is logged in                            
   echo '<none>' > /tmp/snmp/user
   /etc/rc.d/init.d/snmpd start
fi 


update_progress "96" "keytable start"
if [ -f /etc/rc.d/init.d/keytable ]; then
   /etc/rc.d/init.d/keytable start
fi 
 
update_progress "98" "caching profiles"
#if [ -f /etc/rc.d/rc.local ]; then
#   /etc/rc.d/rc.local
#fi



# Cache profiles to flash card -- if configured.
/IBM/bin/cache_profiles.sh machine


update_progress "100"  "software update"

# Do flash recovery or software update if needed
/IBM/bin/readNvram 43
/IBM/bin/readNvram 78
flashRec=`/bin/cat /tmp/snmp/43`
softwareUpd=`/bin/cat /tmp/snmp/78`
if [ "$flashRec" = "1" -o "$softwareUpd" = "1" ]; then
        # Flash recovery or software update needed...

        # Copy softwareUpdate.sh to /tmp and run it from there.
        # This avoids having the file in-use if IBM.cramfs is replaced. 
        cp -a /IBM/bin/softwareUpdate.sh /tmp

        # Exec the softwareUpdate script.  This frees up the /etc
        # device in case we're doing a software update and etc.cramfs
        # is replaced

        # NOTE: this section of code needs to be late in this script.
        # softwareUpdate.sh might return without doing the update,
        # and we want to keep booting normally.
        # Putting this before services avoids having nfsd, etc
        # running during the update.
        exec /tmp/softwareUpdate.sh
fi

# Initialize nfs, telnet, and seriald services.
/etc/rc.d/rc.IBM_NS.services

# Initialize authentication scheme and pam/nss configurations.
/etc/rc.d/rc.IBM_NS.auth

# Configure home directory mount from profile information.
/etc/rc.d/rc.IBM_NS.home

if [ -e /etc/rc.d/rc.local ]; then
   /etc/rc.d/rc.local
fi


# Upgrade SU3 boot prom if necessary
# Now done in 2x00 script
#if [ -f /IBM/bin/reflash_2x00.sh ]; then
#  /IBM/bin/reflash_2x00.sh
#fi



