#!/bin/sh
################################################################################
# Name: common_install.sh
# Purpose: Portiopns of the install process common to all distributions
# Last edited: 10/22/2001
# Command:
#    common_install.sh
# Input (via environment variables), set by calling program:
#    CLIENT_VENDOR - vendor name (RedHat, Caldera, TurboLinux)
#    CLIENT_DISTRIBUTION  (example: 6.1, WorkStation6.0, etc)
#    RPM_LIST_FILE - file name for client rpm list to install
################################################################################

PATH=$PATH:/sbin:/usr/sbin:/bin:/usr/bin

export DEFAULT_MOUNTPOINT=/tmp/nsinstall
export MOUNTPOINT=/nstation/install
export SU4INSTALLED=n

function getNFSServer 
{
        if [ -n "$NFSSERVER" ]; then
                echo -n "What is the NFS Install Server IP Address? [ $NFSSERVER ]: "
                read -r nfsserver_answer
                check_valid ${nfsserver_answer:="$NFSSERVER"} "getNFSServer"
        else
                echo -n "What is the NFS Install Server IP Address?: "
                read -r nfsserver_answer
                check_valid ${nfsserver_answer:-"not set"} "getNFSServer"
        fi
        NFSSERVER=$nfsserver_answer
}

function getMountPoint
{
	echo -n "What is the NFS Source Installation Directory?: "; read MOUNTPOINT
	if [ ! $MOUNTPOINT ]
		then 
			echo -e "\nNo value set.  Using defaults.\n"
			MOUNTPOINT=/nstation/install
	fi
}

function listMountPoints
{
        # If we have an old version of bash OR the showmount command doesn't
        # exist on this system, then don't list the mount points, just prompt
        # the user to enter.
        if [ -z "$CAN_LIST_MOUNT_POINTS" ]; then
                CAN_LIST_MOUNT_POINTS=true
                if [ "`echo $BASH_VERSION | cut -d. -f1`" -lt 2 ]; then
                        CAN_LIST_MOUNT_POINTS=false
                elif [ -z "`which showmount | grep /showmount`" ]; then
                        CAN_LIST_MOUNT_POINTS=false
                fi
        fi

        if [ "$CAN_LIST_MOUNT_POINTS" = "false" ]; then
                getMountPoint
        else

                allow_default=false

                echo -e "\nAvailable mounts on: $NFSSERVER\n\n"
                LINECOUNT=`showmount -e $NFSSERVER | wc -l`
                TEMP=`showmount -e $NFSSERVER | grep -vE "Export list" | tr -s "*" " " | cut -f1 -d" " | tr -s "\n" "\t"`
                TEMPC=1	
                while [ $TEMPC -lt $LINECOUNT ]; do

                        MountArray[$TEMPC]=`echo $TEMP | cut -f$TEMPC -d" " | cut -f1 -d" "`

                        if [ "$allow_default" = "false" -a "$MOUNTPOINT" = "${MountArray[$TEMPC]}" ]; then
                                allow_default=true
                        fi

                        echo -e "\t $TEMPC. ${MountArray[$TEMPC]}"
                        TEMPC=$((TEMPC+1))
                done
                if [ "$allow_default" = "true" ]; then
                        echo -e "\n"
                        echo -e "\t    Enter key selects default [$MOUNTPOINT]"
                fi
                echo -e "\n"
                echo -n "Choose a mount point: "; read -r SELECT
                if [ -n "$SELECT" ]; then
                        checkForRange $SELECT $((LINECOUNT-1)) "listMountPoints"
                        MOUNTPOINT=${MountArray[$SELECT]}
                else
                        if [ "$allow_default" = "false" ]; then
                                listMountPoints
                        fi
                fi
        fi
}


function unmountNFSServer
{
	echo -n "Unmounting Server..."
	umount $DEFAULT_MOUNTPOINT 
}

function mountNFSServer
{
	if [ $MOUNTPOINT ] && [ $NFSSERVER ]
		then 
			echo -e "\n\n"
			echo  "Mounting $NFSSERVER:$MOUNTPOINT  Please wait..."
 			if [ ! -d $DEFAULT_MOUNTPOINT ]; then
                           mkdir -p $DEFAULT_MOUNTPOINT
                        fi
			# Unmount any left over mounts, before mounting default_mountpoint
			umount $DEFAULT_MOUNTPOINT > /dev/null 2>&1 

			if mount $NFSSERVER:$MOUNTPOINT $DEFAULT_MOUNTPOINT
				then echo -e "Mount successful."
				else
					echo -e " ERROR: Mount unsuccessful. Check $NFSSERVER:$MOUNTPOINT:"
					unmountNFSServer
                                        
                        fi

		else
			echo -e "\n\n"
			echo -e "NFS server and mount point not both specified.\n"
			echo -e "Assuming $IMAGENAME is in file system.\n"
			USINGEXISTINGFS=true

	fi
	echo -e "\n"
}

function check_valid # number callingFunction 
{
        if [ -z "`echo $1 | grep "^[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}$"`" ]; then
		echo -e "\nInvalid value\n";
		$2
        fi
} 

function checkForRange # number upperlimit callingFunction
{
	BADCHOICE=0

        if [ -z "`echo $1 | grep "^[0-9]\{1,\}$"`" ]; then
                BADCHOICE=1
        elif [ $1 -eq 0 ]; then
		umount $DEFAULT_MOUNTPOINT
		sync;sync;sync
		exit 1
        elif [ $1 -lt 1 ]; then
		BADCHOICE=1
        elif [ $1 -gt $2 ]; then
		BADCHOICE=1
	fi

	if [ $BADCHOICE -eq 1 ]; then
		BADCHOICE=0
		echo -e "\nInvalid value.\n"
		$3
	fi
}



function NFS_install
{
        echo ""
        echo "Please select an option:"
        echo "  1. Change NFS Server IP Address [ $NFSSERVER ]"
        echo "  2. Change NFS Source Directory  [ $MOUNTPOINT ]"
        echo "  3. NFS Server IP Address and Source Directory are OK Continue."
        echo "  0. Quit - Abort installation."
        echo -n "Enter Selection: "; read
        case $REPLY in
                [1])    getNFSServer
                        listMountPoints
                        NFS_install;;
                [2])    listMountPoints
                        #create_directory NFS
                        NFS_install;;  
                [3])    ;;  
                [0])    rm -f tmp/bootDirValue
                        exit 1;;  
                  *)
                        echo -e "\n\nInvalid Response\n\n"
                        NFS_install;;
        esac
}

function NFS_or_CDROM_install
{
	echo "Please select Installation type:"
	echo "  1. Local CDROM "
	echo "  2. NFS"
        echo -n "Enter Selection: "; read
	case $REPLY in
		[1])    INSTALLTYPE=cdrom 
                        create_directory CDROM;;
		[2])    INSTALLTYPE=nfs 
                        getNFSServer
#                       getMountPoint
                        listMountPoints
#		        create_directory NFS
              NFS_install
                        mountNFSServer
			cdrom=$DEFAULT_MOUNTPOINT
                        ;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			NFS_or_CDROM_install;;
	esac
}

function verifyInstallDir
{
	mountNFSServer
        if [  -d $DEFAULT_MOUNTPOINT/TurboLinux ]; then
                echo -e "Installation source directory is OK. \n"
        else
                echo -e "Check NFS Server Installation source directory and IP Address . \n"
                echo -n "Abort Installation [y] (y/n)?"; read input
	case $input in
		""|[yY]|[yY][eE][sS]) exit 1;;
		[nN]|[nN][oO])NFS_install;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			verifyInstallDir;;
	esac
        fi
}


function create_directory
{
        case $1 in
                "NFS")
                        dir_prompt="Local Mount Point for NFS"
                        default_dir="/mnt/nfsinstall"
                        dir_var="MOUNTPOINT"
                ;;
                "CDROM")
                        dir_prompt="Mount Point for CDROM"
                        default_dir="/mnt/cdrom"
                        dir_var="cdrom"
                ;;
                "PRODUCT")
                        dir_prompt="Base Product Directory"
                        default_dir="/nstation"
                        dir_var="BASE_PRODUCT_DIR"
                ;;
                "CLIENT")
                        dir_prompt="Client Installation Directory"
                        default_dir="${BASE_PRODUCT_DIR:-"/nstation"}/linux"
                        dir_var="BOOT_DIR"
                ;;
                "MACHINE")
                        dir_prompt="Client Machine Specific Directory"
                        default_dir="${BASE_PRODUCT_DIR:-"/nstation"}/machines"
                        dir_var="MACHINE_BASE_DIR"
                ;;
                "PROFILE")
                        dir_prompt="Client Profile Directory"
                        default_dir="${BASE_PRODUCT_DIR:-"/nstation"}/profiles"
                        dir_var="PROFILE_BASE_DIR"
                ;;
                "HOME")
                        dir_prompt="Client User Home Directory"
                        default_dir="${BASE_PRODUCT_DIR:-"/nstation"}/home"
                        dir_var="HOME_BASE_DIR"
                ;;
               	 
        esac
        dir_done="false"
        while [ "$dir_done" = "false" ]; do
                if [ "$1" = "CLIENT" -o "$1" = "MACHINE" -o "$1" = "PROFILE" -o "$1" = "HOME" ]; then
                 	export dir_val=$default_dir
                else
                	echo -n "$dir_prompt [$default_dir] ? "; read dir_val
                	if [ ! $dir_val ]; then
                                export dir_val=$default_dir
                	else
                        	case $dir_val in
                                        [yY]|[yY][eE][sS])
                                                export dir_val=$default_dir;;          
                                esac
                	fi
                fi
		if [ -d $BASE_PRODUCT_DIR/linux/etc/bootstrap.d ]; then
   		   # this is a server with some version of SU4 already installed
   		   # we will still updated files, but will not migrate any profiles
  		   export SU4INSTALLED=y
		fi
                if [ -d $dir_val ]; then
	#		if [ $1 = "CLIENT" -a $SU4INSTALLED = "n" ]; then
			if [ $1 = "CLIENT" ]; then
				echo -n "Detected existing installation.   Would you like to Upgrade (preserving client configurations) or perform a Re-install (the previous installation will be removed)? (U/R) "
				read input
			        case $input in
					[Uu]) 
					MIGRATE_HOME=n
					echo -n "System default configurations will automatically be migrated.  Would you also like user and workstation configurations to be migrated? (y/n) "
					read migrate_input
					case $migrate_input in
						[yY])
						MIGRATE_HOME=y
						;; 
						[nN])
						MIGRATE_HOME=n
						;;
					esac 
					;;
					[Rr]) echo "Removing previous install...."
						rm -Rf $dir_val 
						CLIENT_UNINSTALL=y
					;;
       	         			*)
		                        echo -e "\n\nInvalid Response\n\n"
					create_directory $1;;
			        esac

			elif [ $1 = "MACHINE" ]; then
				if [ "$CLIENT_UNINSTALL" = "y" ]; then
					rm -Rf $dir_val
					mkdir -p $dir_val
				fi
			elif [ $1 = "PROFILE" ]; then
				if [ "$CLIENT_UNINSTALL" = "y" ]; then
					rm -Rf $dir_val
					mkdir -p $dir_val
					chown 0:0 $dir_val
					chmod 755 $dir_val
				fi
                        elif [ $1 = "HOME" ]; then
                                if [ "$CLIENT_UNINSTALL" = "y" ]; then
                                        rm -Rf $dir_val
                                        mkdir -p $dir_val
                                        chown 0:0 $dir_val
                                        chmod 755 $dir_val
                                fi
			fi
                        export $dir_var=$dir_val
                        dir_done="true"
                elif [ "$1" = "CLIENT" -o "$1" = "MACHINE" -o "$1" = "PROFILE" -o "$1" = "HOME" ]; then
                        export $dir_var=$dir_val
                        mkdir -p $dir_val
                        if [ "$1" = "PROFILE" ]; then
                        	chown 0:0 $dir_val
                        	chmod 755 $dir_val
                        fi
                        dir_done="true"
                else
                        echo -n "$dir_prompt does not exist. Create $dir_val? "; read ans
                        case $ans in
                                ""|[yY]|[yY][eE][sS])
                                mkdir -p $dir_val
                                if [ -d $dir_val ]; then
                                        export $dir_var=$dir_val
                                        dir_done="true"
                                fi
                                ;;              
                                [nN]|[nN][oO]) ;;
                                *)
                                        echo -e "\n\nInvalid Response\n\n"
                                        continueQuestion;;
                        esac
                fi
        done
}


################################################################################
# continueQuestion
################################################################################
function continueQuestion
{
	echo -ne "\nDo you wish to continue, restart, or exit installation? (c/r/e) "
	read input
	case $input in
		[cC]|[Cc][Oo][Nn][Tt][Ii][Nn][Uu][Ee]) ;;
		[Rr]|[Rr][Ee][Ss][Tt][Aa][Rr][Tt]) main_common ;;
		[nN]|[nN][oO]|[eE]|[Ee][Xx][Ii][Tt]) exit 1;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			continueQuestion;;
	esac
}

################################################################################
# preInstall_Verifications
################################################################################
function preInstall_Verifications
{


   # create a new tmp/bootDirValue file - holds boot, server, and other info 
   if [ -f tmp/bootDirValue ]; then
      rm -f tmp/bootDirValue
   fi
   touch tmp/bootDirValue

   if [ -f tmp/error ]; then
      rm -f tmp/error
   fi

	# Be sure path contains local directory
	PATH=$PATH:.

	# If the current working directory is the same as the CDROM we should exit
	# as this can cause problems with mounting/unmounting the CDROMS
	if [ $CURDIR = $cdrom ]; then
		echo -e "\nDo not launch this installation from within the CDROM mount point.\n"
		exit 1
	fi

	# Prompt the end user for the server IP Address and verify it is a valid IP
	# getServerIP
	findServerIP

	# Prompt the end user for the server's Linux distribution
	serverDistribution

	# Prompt the end user for the installation directory
   echo
   create_directory PRODUCT
   create_directory CLIENT
	echo "BOOT_DIR=$BOOT_DIR" >> tmp/bootDirValue
}

################################################################################
# setMachineBaseDir
################################################################################
#function setMachineBaseDir
#{
#  echo ""
#  echo "In normal installations, the client defines a RAMdisk to hold temporary data."
#  echo -n "Should the boot server hold client specific data (e.g. /tmp) [ No ] ? (Yes/No) "
#  read input
#  case $input in
#    [yY]|[yY][eE][sS])
#        echo "create_directory [0]"
#        create_directory MACHINE
#      # Ask if temporary client data should be refreshed on every boot
#      echo -n "Do you want client specific data persistent "
#      echo -n "across client boot sessions [ No ] ? (Yes/No) "
#      read persistent
#      case $persistent in
#        [yY]|[yY][eE][sS])
#          MACHINE_DATA_PERSISTENT=y;;
#        *)
#          MACHINE_DATA_PERSISTENT=n;;
#      esac
#      ;;
#    *)
#      unset MACHINE_BASE_DIR;;
#  esac
#}
#
#function setMachineBaseDirType
#{
#	echo ""
#	echo -n "Machine specific directories based on MAC address or IP address [ MAC ] (IP/MAC) ? "
#	read input
#	case $input in 
#		MAC | mac)
#			MACHINE_DIRECTORY_TYPE=MAC;;
#		IP | ip)
#			MACHINE_DIRECTORY_TYPE=IP;;
#		*)
#			MACHINE_DIRECTORY_TYPE=MAC;;
#	esac
#}

function findServerIP
{
   interface=`route -n | grep 'UG' | awk '{print $8}'`
   if [ ! $interface ]; then
      getServerIP
   else
      IP=`/sbin/ifconfig $interface | grep "inet addr" | awk '{print $2}' | cut -d":" -f2`

      getServerIP $IP
   fi

}

################################################################################
# getServerIP
################################################################################
function getServerIP
{

	while [ ! $validIP ]
	do
		echo -ne "\nServer IP Address: [ $1 ] ? "; read IP
                if [ ! $IP ]; then
						IP=$1
                fi
		TEMP=`echo $IP | tr -d "[a-z][A-Z][\-\"]"`
		if [ ${#TEMP} -ne ${#IP} ]; then
			if [ ! $validIP ]; then
				echo -e "\nInvalid value"; getServerIP;
			fi
		fi
 
		TEMP=`echo $IP | cut -f1 -d"."`
		if [ $TEMP -gt 255 ]; then
			if [ ! $validIP ]; then
				echo -e "\nInvalid value"; getServerIP;
			fi
		fi
		TEMP=`echo $IP | cut -f2 -d"."`
		if [ $TEMP -gt 255 ]; then
			if [ ! $validIP ]; then
				echo -e "\nInvalid value"; getServerIP;
			fi
		fi
		TEMP=`echo $IP | cut -f3 -d"."`
		if [ $TEMP -gt 255 ]; then
			if [ ! $validIP ]; then
				echo -e "\nInvalid value"; getServerIP;
			fi
		fi
		TEMP=`echo $IP | cut -f4 -d"."`
		if [ $TEMP -gt 255 ]; then
			if [ ! $validIP ]; then
				echo -e "\nInvalid value"; getServerIP;
			fi
		fi
		validIP=1
	done
}

################################################################################
# serverDistribution
################################################################################
function serverDistribution
{
	CALDERA="Caldera Open Linux"
	REDHAT="RedHat Linux"
	SUSE="SuSe Linux"
	TURBO="TurboLinux"
	OTHER="Other"
	
	echo ""
	PS3="Which Linux distribution are you running on this server? "
	select i in "$CALDERA" "$REDHAT" "$SUSE" "$TURBO" "$OTHER"
	do
		case $i in
			"$CALDERA")
				DISTRIBUTION="$CALDERA"
				break;;
			"$REDHAT")
				DISTRIBUTION="$REDHAT"
				break ;;
			"$SUSE")
				DISTRIBUTION="$SUSE"
				break ;;
			"$TURBO")
				DISTRIBUTION="$TURBO"
				break ;;
			"$OTHER")
				DISTRIBUTION="$OTHER"
				break ;;
		esac
	done
	echo "SERVER=\"$DISTRIBUTION\"" >> tmp/bootDirValue

}

################################################################################
# Main Body
################################################################################
function main_common 
{
set +x
umask 022

CLIENT_UNINSTALL=n

if [ -d $BASE_PRODUCT_DIR/linux/etc/bootstrap.d ]; then
   # this is a server with some version of SU4 already installed
   # we will still updated files, but will not migrate any profiles
   export SU4INSTALLED=y
fi

# determine rpm version and use newer version if necessary
RPMVERSION=`rpm --version | awk {'print $NF'} | sed 's/\.//g' | cut -c 1,2,3`
if [ $RPMVERSION -lt 306 ]; then
   RPM_CMD="Common/scripts/rpm --rcfile Common/scripts/rpmrc"
else
   RPM_CMD=rpm
fi
export RPM_CMD

# Determine if the current user is root - if not, exit
curUser=`whoami`
if [ $curUser != "root" ]; then
   echo -e "This install script must be run while logged in as root\n"
	return 0
fi

NFS_or_CDROM_install

# make sure they have the correct cd to install
if [ -f $cdrom/.build -o -f $cdrom/.BUILD ]; then
   if [ -f $cdrom/.BUILD ]; then
      cdbuild=`cat $cdrom/.BUILD`
   fi

   if [ -f $cdrom/.build -o "$cdbuild" != "200112102" ]; then
      echo "The version of the TurboLinux 7.0 CD is incorrect.  The TurboLinux 7.0 NetVista Build 9 CD is needed."
      touch tmp/error
      return 1
   fi
fi

preInstall_Verifications

echo ""
export cdrom



# ==========  Set Linux distribution specific Variables ===========================

# Default Settings
RC_BOOT_FILE=rc.sysinit
REBOOT_NEEDED=y

valid_client=n

# Specific setting for TurboLinux Client
if [ x$CLIENT_VENDOR = x"TurboLinux" ]; then
   valid_client=y
   REBOOT_NEEDED=y
   # Name of boot file to be modified
   RC_BOOT_FILE=rc.sysinit
   # RPM source directory (ends with slash)
   if [ ! $cdrom ]; then
      RPM_SOURCE_DIR=/mnt/cdrom/turbo/RPMS/
   else
      RPM_SOURCE_DIR=$cdrom/turbo/RPMS/
   fi
fi
  
# Specific setting for RedHat Client
if [ x$CLIENT_VENDOR = x"RedHat" ]; then
   valid_client=y
   REBOOT_NEEDED=n
   # Name of boot file to be modified
   RC_BOOT_FILE=rc.sysinit
   # RPM source directory (ends with slash)
   if [ ! $cdrom ]; then
      RPM_SOURCE_DIR=/mnt/cdrom/RedHat/RPMS/
   else
      RPM_SOURCE_DIR=$cdrom/RedHat/RPMS/
   fi
fi

# Specific setting for Mandrake Client
if [ x$CLIENT_VENDOR = x"Mandrake" ]; then
   # RPM source directory (ends with slash)
   if [ ! $cdrom ]; then
      RPM_SOURCE_DIR=/mnt/cdrom/Mandrake/RPMS/
   else
      RPM_SOURCE_DIR=$cdrom/Mandrake/RPMS/
   fi
   valid_client=y
fi

#check if its a valid client
if [ x$valid_client = x"n" ]; then 
   echo " "
   echo "ERROR: Invalid client vendor specified CLIENT_VENDOR = <$CLIENT_VENDOR>"
   echo "       Run the appropriate wrapper (e.g. tl_create_bootdir_from_rpm.sh)"
   echo "       Installation exiting"
   exit 1
fi

# ==========  Set Common Variables applicable to client distributions ===========================

# Set the dir name of nc specific file - could be in tmp if tmp is a RAM disk, or could
# be in tmp.nc for nc specific files - Whatever is done here must match between 
# this script file and IBM_RC_BOOT_FILE (rc.sysinit.IBM_NS.sboot) file
# script
TMP_DIR=tmp

DEFAULT_MACHINE_BASE_DIR=/nstation/machines
MACHINE_TEMPLATE=NONKIOSK_SBOOT_TEMPLATE
MACHINE_DATA_PERSISTENT=y

#set MACHINE_BASE_DIR - directory that holds client-machine specific data (/tmp, var, etc)
MACHINE_BASE_DIR=$3

# Check for existing installation
CLIENT_UPGRADE=n
if [ -d $BOOT_DIR/var.nc_shared ]; then
   echo ""
   echo "WARNING: Client boot directory set-up exists - This will upgrade the installation"
   CLIENT_UPGRADE=y
   RPM_OPTIONS="--nodeps --force" 
   if [ -f $BOOT_DIR/etc/rc.d/machineDir.IBM_NS.setup ]; then
      . $BOOT_DIR/etc/rc.d/machineDir.IBM_NS.setup 
   else
      create_directory MACHINE
   fi
   create_directory PROFILE
else
   # lets default to machine base dir by default. and persitent data...
   create_directory MACHINE
   create_directory PROFILE
   create_directory HOME

   #setMachineBaseDirType

   # we only have 1 install option now.. authenticated
   MACHINE_TEMPLATE=NONKIOSK_SBOOT_TEMPLATE

fi

# Check if CDROM is mounted and files are present - CHECK if correct CD is present ???
if [ -d $RPM_SOURCE_DIR ]; then
  echo ""
else
  CDMOUNTED=`df | grep $cdrom | grep -v grep | wc -l`
  if [ $CDMOUNTED != 0 ]; then
    umount $cdrom
  fi
  CDMOUNTED=0
  while [ $CDMOUNTED = 0 ]
  do
    echo -e "\nPlease insert the $CLIENT_VENDOR $CLIENT_DISTRIBUTION CD"
    echo -n "   Press <ENTER> To Continue "; read
    echo ""
    CDMOUNTED=`df | grep $cdrom | grep -v grep | wc -l`
    if [ $CDMOUNTED = 0 ]; then
      mount $cdrom
      CDMOUNTED=`df | grep $cdrom | grep -v grep | wc -l`
    fi
    # Check if its the correct CD
    if [ ! -d $RPM_SOURCE_DIR ]; then
      umount $cdrom
      CDMOUNTED=0
    fi
  done
fi

# turbolinux - grep "^VERSION" version.cfg | cut -d'=' -f2
if [ $CLIENT_VENDOR = "TurboLinux" ]; then
   if [ -f "$cdrom/version.cfg" ]; then
      VERSION=`grep "^VERSION" $cdrom/version.cfg | cut -d'=' -f2`
   fi
   export CLIENT_DISTRIBUTION="$CLIENT_DISTRIBUTION $VERSION"
fi

if [ $BOOT_DIR = "/" ]; then
  echo -e "\nERROR: Attempting to install on the '/' directory - This will CORRUPT your server set-up"
  echo -e "         Installion terminating"
  exit 1
fi

if [ ! "$HOME_BASE_DIR" ]; then
   HOME_BASE_DIR="$BASE_PRODUCT_DIR/home"
fi


echo "Installation of Server Boot $CLIENT_VENDOR $CLIENT_DISTRIBUTION Linux client for IBM NetVista thin client"
echo "Current selections: " 
echo "   Server IP address:          " $IP
echo "   Base product directory:     " $BASE_PRODUCT_DIR
echo ""
echo "Exported directories: "
echo "   Client boot directory:      " $BOOT_DIR
echo "   Client specific directory:  " $MACHINE_BASE_DIR
echo "   Client profiles directory:  " $PROFILE_BASE_DIR
echo "   Client user home directory: " $HOME_BASE_DIR

mkdir -p $HOME_BASE_DIR

# Be sure the administrator wants to continue the installation with these settings
continueQuestion

# Remove the exported directories for this install.
grep -v $BOOT_DIR /etc/exports > /tmp/.exports1
grep -v $MACHINE_BASE_DIR /tmp/.exports1 > /tmp/.exports2
grep -v $PROFILE_BASE_DIR /tmp/.exports2 > /tmp/.exports1
grep -v $HOME_BASE_DIR /tmp/.exports1 > /tmp/.exports2
mv /tmp/.exports2 /etc/exports
rm /tmp/.exports1

# Reload the nfs server with the temporary /etc/exports file.
if [ -f /etc/rc.d/init.d/nfsserver ]; then
   /etc/rc.d/init.d/nfsserver reload
elif [ -f /etc/rc.d/nfs ]; then
   /etc/rc.d/nfsserver reload
else
   /etc/rc.d/init.d/nfs reload
fi

# Create the directories, files needed for next step of RPM installation
if [ x$CLIENT_UPGRADE = x"y" -a $SU4INSTALLED = "n" ]; then 
  echo "Set-up for UPGRADE INSTALL "

   if [ -d $BOOT_DIR/var.nc_shared ]; then
      rm -f $BOOT_DIR/var
      mv $BOOT_DIR/var.nc_shared $BOOT_DIR/var
   fi

   $RPM_CMD --root $BOOT_DIR --rebuilddb

   # Remove previously shipped IBM IDFs
   rm -f $BOOT_DIR/IBM/update/idf/TurboLinux607_2200_Navigator_ICA6_IBM3270_IBM5250.idf
   rm -f $BOOT_DIR/IBM/update/idf/TurboLinux607_2800_Navigator_ICA6_IBM3270_IBM5250.idf
   rm -f $BOOT_DIR/IBM/update/idf/TurboLinux607_2x00_Communicator_ICA6_IBM3270_IBM5250_48MB.idf

   # Move all other IDFs to another directory.
   echo "Move pre-SU4 IDFs to $BOOT_DIR/IBM/update/.old/idf/"
   mkdir -p $BOOT_DIR/IBM/update/.old/idf/
   grep "HEAD " $BOOT_DIR/IBM/update/idf/*.idf | grep -v "IBM_VERSION=V3R2M0S0" | cut -d: -f1 | xargs -n1 -i mv {} $BOOT_DIR/IBM/update/.old/idf/

   # Remove previously shipped IBM SDFs
   rm -f $BOOT_DIR/IBM/update/sdf/ICAClient6.0-minimal.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/ICAClient6.0.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/TurboLinux607_Navigator477-minimal.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/TurboLinux607_Navigator477.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/TurboLinux607_Print.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/TurboLinux607_fvwm2.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/TurboLinux607_ghostscript.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/TurboLinux607_icewm.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/TurboLinux607_x3270.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/TurboLinux607_BaseOS.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/TurboLinux607_ICAClient-3.0-4.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/1-2_Migration.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/2-3_Migration.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/TurboLinux607_Communicator477.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/NetVista_2200_Support.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/NetVista_2800_Support.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/RAM_Disk_Configuration_Data.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/TurboLinux607_fvwm2.sdf
   rm -f $BOOT_DIR/IBM/update/sdf/peerboot.sdf

   # Move all other non-V3R2M0S0 SDFs to another directory.
   echo "Move pre-SU4 SDFs to $BOOT_DIR/IBM/update/.old/sdf/"
   mkdir -p $BOOT_DIR/IBM/update/.old/sdf/
   grep "HEAD " $BOOT_DIR/IBM/update/sdf/*.sdf | grep -v "IBM_VERSION=V3R2M0S0" | cut -d: -f1 | xargs -n1 -i mv {} $BOOT_DIR/IBM/update/.old/sdf/


  # MACHINE_BASE_DIR -> /nstation/blahblahblah
  # MACHINE_TEMPLATE -> NONKIOSK_SBOOT_TEMPLATE or KIOSK_SBOOT_TEMPLATE
  # MACHINE_DIRECTORY_TYPE -> MAC or IP

  if [ -d $BOOT_DIR/IBM/migration ]; then
     rm -Rf $BOOT_DIR/IBM/migration
  fi

  mkdir -p $BOOT_DIR/IBM/migration/home/root

  if [ -e $BOOT_DIR/etc/rc.d/machineDir.IBM_NS.setup ]; then
     cp $BOOT_DIR/etc/rc.d/machineDir.IBM_NS.setup $BOOT_DIR/IBM/migration/home
  fi


  if [ $MACHINE_TEMPLATE = "NONKIOSK_SBOOT_TEMPLATE" ]; then

    cp -a $BOOT_DIR/home/* $BOOT_DIR/IBM/migration/home
    cp -a $BOOT_DIR/home/.[^.]* $BOOT_DIR/IBM/migration/home
    cp -a $BOOT_DIR/root/* $BOOT_DIR/IBM/migration/home/root
    cp -a $BOOT_DIR/root/.[^.]* $BOOT_DIR/IBM/migration/home/root

  fi

  if [ -e $BOOT_DIR/home/sys-default ]; then
     cp -a $BOOT_DIR/home/sys-default/* $BOOT_DIR/IBM/migration/home/root
     cp -a $BOOT_DIR/home/sys-default/.[^.]* $BOOT_DIR/IBM/migration/home/root
  fi
  if [ -e $BOOT_DIR/etc/sysconfig ]; then
     cp -a $BOOT_DIR/etc/sysconfig/* $BOOT_DIR/IBM/migration/home/root
     cp -a $BOOT_DIR/etc/sysconfig/.[^.]* $BOOT_DIR/IBM/migration/home/root
  fi

  # copy over machine specific data....
  for i in `ls $MACHINE_BASE_DIR`
  do
    if [ -d $MACHINE_BASE_DIR/$i/tmp/home/KIOSK ]; then
      mkdir -p $BOOT_DIR/IBM/migration/home/$i
      cp -a $MACHINE_BASE_DIR/$i/tmp/home/KIOSK/* $BOOT_DIR/IBM/migration/home/$i
      cp -a $MACHINE_BASE_DIR/$i/tmp/home/KIOSK/.[^.]* $BOOT_DIR/IBM/migration/home/$i
    fi

    cp $MACHINE_BASE_DIR/$i/tmp/var/snmp/snmpd.local.trap $BOOT_DIR/IBM/migration/home/$i
    if [ -d $MACHINE_BASE_DIR/tmp/root ]; then

       if [ ! -d $BOOT_DIR/IBM/migration/home/$i/root ]; then
          mkdir -p $BOOT_DIR/IBM/migration/home/$i/root
       fi
       cp -a $MACHINE_BASE_DIR/tmp/root/* $BOOT_DIR/IBM/migration/home/$i/root
       cp -a $MACHINE_BASE_DIR/tmp/root/.[^.]* $BOOT_DIR/IBM/migration/home/$i/root
  fi    
  done

 
  # modifiy KIOSK entry in passwd file 
  sed 's/home\/KIOSK/tmp\/KIOSK/' $BOOT_DIR/etc/passwd > /tmp/passwd
  cp -f /tmp/passwd $BOOT_DIR/etc 

  mkdir $BOOT_DIR/IBM/migration/etc
  cp $BOOT_DIR/etc/group $BOOT_DIR/IBM/migration/etc
  cp $BOOT_DIR/etc/group- $BOOT_DIR/IBM/migration/etc
  cp $BOOT_DIR/etc/passwd $BOOT_DIR/IBM/migration/etc
  cp $BOOT_DIR/etc/passwd- $BOOT_DIR/IBM/migration/etc
  cp $BOOT_DIR/etc/shadow $BOOT_DIR/IBM/migration/etc
  cp $BOOT_DIR/etc/shadow- $BOOT_DIR/IBM/migration/etc

  cp $BOOT_DIR/etc/printcap $BOOT_DIR/IBM/migration/etc

  if [ $MIGRATE_HOME = "y" -a $SU4INSTALLED = "n" ]; then
      touch $BOOT_DIR/IBM/migration/migrate.home
  fi

  tar -czvf /tmp/migration.tar.gz -C $BOOT_DIR/IBM migration

elif [ x$CLIENT_UPGRADE = x"y" -a $SU4INSTALLED = "y" ]; then 
      if [ -d $BOOT_DIR/var.nc_shared ]; then
         rm -f $BOOT_DIR/var
         mv $BOOT_DIR/var.nc_shared $BOOT_DIR/var
      fi
      echo "Set-up for a UPGRADE INSTALL without profile migration."
      mkdir -p $BOOT_DIR/tmp/var/lib/rpm
      $RPM_CMD --root $BOOT_DIR --rebuilddb
else
  # ============  Create infrastructure for RPM installation  =================
  # create the boot dir - do we need to check is boot image has alredy been created
  Common/scripts/mkdirhier ${BOOT_DIR}

  ./install_prep.sh $BOOT_DIR
  echo "Set-up for NEW INSTALL "
  cp -pR RPM_INSTALL_PREREQ/*   $BOOT_DIR
fi

# ============  Install RPMS from a shell script =================
if [ ! -f $RPM_LIST_FILE -a ! -f $RPM_LIST_FILE.1 ]; then
   echo ERROR: No rpm list file $RPM_LIST_FILE present - Check the package
   exit 1
fi

# older versions of Caldera will need this symlink created
if [ "$DISTRIBUTION" = "$CALDERA" -a "$RPM_CMD" = "Common/scripts/rpm" ]; then
   if [ ! -e /usr/lib/rpm ]; then
      ln -s `find /usr/lib -type d -name rpm-*` /usr/lib/rpm
   fi
fi    

echo "INSTALLING RPMS....."

if [ $CLIENT_UPGRADE = "n" ]; then
   $RPM_CMD --initdb $BOOT_DIR/var/lib/rpm --root $BOOT_DIR
else
  	# remove netscape dir since new netscape rpm won't uninstall or
	# or upgrade properly with ica plugin laying around...
 	rm -Rf $BOOT_DIR/usr/lib/netscape*
	if [ -f uninstall.list ]; then
		$RPM_CMD -e --root $BOOT_DIR `cat uninstall.list` 2> tmp/rpm.err | tee tmp/rpm.log
	fi

fi

# pre-install of distribution specific RPMS like kernel and other
# rpms that we need to just update the database but not really install
if [ -f pre_install_RPMS.sh ]; then
  pre_install_RPMS.sh $BOOT_DIR
fi

if [ "$NUMCDS" != "2" -o $INSTALLTYPE = "nfs" ]; then
    if [ $INSTALLTYPE = "nfs" -a "$NUMCDS" = "2" ]; then
       # echo "cat $RPM_LIST_FILE.1 $RPM_LIST_FILE.2 > tmp/rpmlist.tmp"
       cat "$RPM_LIST_FILE.1" "$RPM_LIST_FILE.2" > tmp/rpmlist.tmp
       RPM_LIST_FILE=tmp/rpmlist.tmp
    fi
    NUMCDS=1
fi

RPM_LIST_FILE_ORIG=$RPM_LIST_FILE

iterations=0
while [ $iterations -lt $NUMCDS ]
do
   if [ $NUMCDS = "2" -a $INSTALLTYPE != "nfs" ]; then
      let tmpnum=iterations+1
      RPM_LIST_FILE="$RPM_LIST_FILE_ORIG.$tmpnum"
   fi 

   ./Common/scripts/makeRPMSlist.sh $RPM_LIST_FILE $RPM_SOURCE_DIR

   if [ $NUMCDS = "2" -a $INSTALLTYPE != "nfs" -a $iterations = "0" ]; then
      $RPM_CMD -Uvh $RPM_OPTIONS --replacepkgs --ignorearch --root $BOOT_DIR `cat tmp/rpm.list`  2>tmp/rpm.err | tee tmp/rpm.log
	else   
      $RPM_CMD -Uvh $RPM_OPTIONS --replacepkgs --ignorearch --root $BOOT_DIR `cat tmp/rpm.list` 2>tmp/rpm.err | tee tmp/rpm.log

	fi

   rc=$?
   if [ ! -f $BOOT_DIR/sbin/init ]; then
      # i couldn't find any good documenation on rpm return codes so 
      # i am assuming that if init isn't there we had a problem
      echo "rpm install failed with return code $rc"
      exit 1
   fi

   let iterations+=1

   if [ $NUMCDS = "2" -a $iterations -lt $NUMCDS ]; then
      umount $cdrom
      echo -e "\nPlease insert the 2nd cd"
      echo -n "   Press <ENTER> To Continue "; read
      mount $cdrom
   fi

done


if [ -f post_install_RPMS.sh ]; then
   post_install_RPMS.sh $BOOT_DIR
fi

# remove /home directory, so that link to /tmp/mnt/home can be created
rm -rf $BOOT_DIR/home

# remove the bogus /etc/X11/gdm directory from gdm2.2
rm -rf $BOOT_DIR/etc/X11/gdm

echo ""

# ============ Create  /etc/fstab file  ========================
echo "Create " $BOOT_DIR"/etc/fstab file"
if [ -f $BOOT_DIR/etc/fstab.org ]; then
  echo $BOOT_DIR/etc/fstab.org file already exists
else
  if [ -f $BOOT_DIR/etc/fstab ]; then
    mv $BOOT_DIR/etc/fstab $BOOT_DIR/etc/fstab.org
  fi
fi
echo "## Generated for IBM Network Station " > $BOOT_DIR/etc/fstab
echo $IP:$BOOT_DIR " /  nfs  defaults  1 1" >> $BOOT_DIR/etc/fstab
echo "none   /proc  proc     defaults  0 0" >> $BOOT_DIR/etc/fstab
echo "none   /dev/pts   devpts  gid=5,mode=620  0 0" >> $BOOT_DIR/etc/fstab

# =====================================================================================
#   Rename unneeded services  
# =====================================================================================
echo "Rename services not needed for IBM NetVista Thin Clients"
if [ -L $BOOT_DIR/etc/rc.d/init.d/linuxconf ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/linuxconf $BOOT_DIR/etc/rc.d/init.d/linuxconf.sav
fi

if [ -f $BOOT_DIR/etc/rc.d/init.d/xinetd ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/xinetd $BOOT_DIR/etc/rc.d/init.d/xinetd.sav
fi

if [ -f $BOOT_DIR/etc/rc.d/init.d/FreeWnn ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/FreeWnn $BOOT_DIR/etc/rc.d/init.d/FreeWnn.sav
fi

if [ -f $BOOT_DIR/etc/rc.d/init.d/canna ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/canna $BOOT_DIR/etc/rc.d/init.d/canna.sav
fi

if [ -f $BOOT_DIR/etc/rc.d/init.d/anacron ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/anacron $BOOT_DIR/etc/rc.d/init.d/anacron.sav
fi

if [ -f $BOOT_DIR/etc/rc.d/init.d/linuxconf ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/linuxconf $BOOT_DIR/etc/rc.d/init.d/linuxconf.sav
fi

if [ -f $BOOT_DIR/etc/rc.d/init.d/gdm ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/gdm $BOOT_DIR/etc/rc.d/init.d/gdm.sav
fi

if [ -f $BOOT_DIR/etc/rc.d/init.d/sound ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/sound $BOOT_DIR/etc/rc.d/init.d/sound.sav
fi

if [ -f $BOOT_DIR/etc/rc.d/init.d/gpm ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/gpm $BOOT_DIR/etc/rc.d/init.d/gpm.sav
fi

if [ -f $BOOT_DIR/etc/rc.d/init.d/junkbuster ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/junkbuster $BOOT_DIR/etc/rc.d/init.d/junkbuster.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/xfs ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/xfs $BOOT_DIR/etc/rc.d/init.d/xfs.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/atd ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/atd      $BOOT_DIR/etc/rc.d/init.d/atd.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/apmd ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/apmd      $BOOT_DIR/etc/rc.d/init.d/apmd.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/kudzu ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/kudzu    $BOOT_DIR/etc/rc.d/init.d/kudzu.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/crond ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/crond    $BOOT_DIR/etc/rc.d/init.d/crond.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/nfs ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/nfs    $BOOT_DIR/etc/rc.d/init.d/nfs.sav
fi
#if [ -f $BOOT_DIR/etc/rc.d/init.d/syslog ]; then
#  mv  $BOOT_DIR/etc/rc.d/init.d/syslog    $BOOT_DIR/etc/rc.d/init.d/syslog.sav
#fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/sendmail ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/sendmail    $BOOT_DIR/etc/rc.d/init.d/sendmail.sav
fi

if [ -f $BOOT_DIR/etc/rc.d/init.d/random ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/random $BOOT_DIR/etc/rc.d/init.d/random.sav
fi





# =====================================================================================
#   Add new files
# =====================================================================================
echo "Add new Common Files "
cp -dfpR Common/COMMON_FILES/*  $BOOT_DIR
echo "Add $CLIENT_VENDOR $CLIENT_DISTRIBUTION Specific Files "
cp -dfpR SPECIFIC_FILES/*  $BOOT_DIR
# Force /tmp directory be RW - Some server setup (Caldera) has $BOOT_DIR/tmp set to RW for root only
chmod a+w $BOOT_DIR/tmp


echo "Adding files from Turbo CD"
mkdir -p $BOOT_DIR/tmp/install
tar -xzf $cdrom/custom/Custom.tgz -C $BOOT_DIR/tmp/install
cp -dfpR $BOOT_DIR/tmp/install/Common/COMMON_FILES/*  $BOOT_DIR
cp -dfpR $BOOT_DIR/tmp/install/TurboLinux/SPECIFIC_FILES/*  $BOOT_DIR
rm -rf $BOOT_DIR/tmp/install

# =====================================================================================
#   Make hard links to kernel
# =====================================================================================
cp $BOOT_DIR/kernel.2200 $BOOT_DIR/kernel.2x00


# =====================================================================================
#   Link files directories to TMP_RAM_DISK - these are uniques file for each client
# =====================================================================================
echo "Link files to RAM disk"
# ==== Create link for var directory (created in RAM disk in /$TMP_DIR)  =======
#Link var directory - var created in ram disk under /$TMP_DIR
if [ -d $BOOT_DIR/var.nc_shared ]; then
  echo "Original var backup already present"
else
  echo "Backup var directory"
  mv $BOOT_DIR/var $BOOT_DIR/var.nc_shared
fi
ln -sf /$TMP_DIR/var $BOOT_DIR/var

#==== Link files used for networking
ln -sf /$TMP_DIR/HOSTNAME     $BOOT_DIR/etc/HOSTNAME
ln -sf /$TMP_DIR/hosts        $BOOT_DIR/etc/hosts
ln -sf /$TMP_DIR/resolv.conf  $BOOT_DIR/etc/resolv.conf
ln -sf /$TMP_DIR/network      $BOOT_DIR/etc/sysconfig/network

#==== Link files used for keyboard
ln -sf /$TMP_DIR/keyboard     $BOOT_DIR/etc/sysconfig/keyboard

#==== Link /etc/mtab file 
if [ -f $BOOT_DIR/etc/mtab ]; then
  rm -f $BOOT_DIR/etc/mtab
fi
ln -sf /$TMP_DIR/mtab $BOOT_DIR/etc/mtab

# link X to /tmp as the X-server could be 4.1 (blue devil) or 3.3.5 (2x00)
ln -sf /$TMP_DIR/X $BOOT_DIR/usr/X11R6/bin/X
ln -sf /$TMP_DIR/XF86Config $BOOT_DIR/etc/X11/XF86Config
ln -sf /$TMP_DIR/XF86Config.N70 $BOOT_DIR/etc/X11/XF86Config-4



# =====================================================================================
#   Perform any client specific operation
# =====================================================================================
if [ x$CLIENT_VENDOR = x"TurboLinux" ]; then
   # for TurboLinux 6.0.5, /etc/services.rpmnew needs to be renames as /etc/servcies
   if [ -f $BOOT_DIR/etc/services.rpmnew ]; then
      mv $BOOT_DIR/etc/services.rpmnew  $BOOT_DIR/etc/services
   fi
fi

# =====================================================================================
#   Set-up Xserver files for FrameBuffer or SVGA 
#   Make sure to change rc.IBM_NS.tmp to make the correct /tmp/XF86Config link
# =====================================================================================
rm -rf $BOOT_DIR/dev
mkdir $BOOT_DIR/dev

rm -f $BOOT_DIR/core

# =====================================================================================
# Create machine specific dir ($MACHINE_BASE_DIR)
#  Template for this set-up is located in BOOT_DIR/IBM?TEMPLATES dir.
# =====================================================================================
if [ "$MACHINE_BASE_DIR" ]; then
   Common/scripts/mkdirhier  ${MACHINE_BASE_DIR}   
   echo "Machine specific template base directory" > ${MACHINE_BASE_DIR}/TEMPLATE_README
fi

# create /etc/rc.d/machineDir.IBM_NS.setup file contain MACHINE dir setup
# if $MACHINE_BASE_DIR is undefined, the file will have NULL value for MACHINE_BASE_DIR
#echo MACHINE_BASE_DIR=$MACHINE_BASE_DIR > $BOOT_DIR/etc/rc.d/machineDir.IBM_NS.setup
#echo MACHINE_TEMPLATE=$MACHINE_TEMPLATE >> $BOOT_DIR/etc/rc.d/machineDir.IBM_NS.setup
#echo MACHINE_DATA_PERSISTENT=$MACHINE_DATA_PERSISTENT >> $BOOT_DIR/etc/rc.d/machineDir.IBM_NS.setup
#echo MACHINE_DIRECTORY_TYPE=$MACHINE_DIRECTORY_TYPE >> $BOOT_DIR/etc/rc.d/machineDir.IBM_NS.setup


# =====================================================================================
# Generate /IBM/linuxDistribution (for version control) and /etc.motd files 
# =====================================================================================
. Common/version
echo -e "$CLIENT_VENDOR $CLIENT_DISTRIBUTION - IBM Version $linux_dist_ver ($linux_dist_date)\n" > $BOOT_DIR/IBM/linuxDistribution
echo -e "Welcome to $CLIENT_VENDOR $CLIENT_DISTRIBUTION - IBM Version $linux_dist_ver ($linux_dist_date)\n" > $BOOT_DIR/etc/motd
# Build $BOOT_DIR/IBM/version file
echo "linux_vendor=$CLIENT_VENDOR" > $BOOT_DIR/IBM/version
echo "linux_dist=$CLIENT_DISTRIBUTION" >> $BOOT_DIR/IBM/version
cat Common/version >> $BOOT_DIR/IBM/version


# =====================================================================================
# Export $BOOT_DIR
# =====================================================================================
temp=`grep $BOOT_DIR /etc/exports`
echo ""

if [ ! "$temp" ]; then
	echo "ETC_EXPORTS_MOD=y" >> tmp/bootDirValue
	if [ "$DISTRIBUTION" = "$REDHAT" ]; then
		echo "$BOOT_DIR		*(rw,no_root_squash)" >> /etc/exports
	elif [ "$DISTRIBUTION" = "$CALDERA" ]; then
		echo -n "Domain name for the clients which will be be booting from this server: "; read
		echo "$BOOT_DIR		*.$REPLY(rw,no_root_squash)" >> /etc/exports
	elif [ "$DISTRIBUTION" = "$TURBO" ]; then
		echo "$BOOT_DIR		*(rw,no_root_squash)" >> /etc/exports
		echo "The TurboLinux NFSd package relies upon the /etc/hosts.allow & /etc/hosts.deny"
		echo "files - if you have troubles booting your client, please consult the"
		echo "man pages for exports, hosts.allow, hosts.deny"
	elif [ "$DISTRIBUTION" = "$SUSE" ]; then
		echo "$BOOT_DIR		*(rw,no_root_squash)" >> /etc/exports
	elif [ "$DISTRIBUTION" = "$OTHER" ]; then
		echo "$BOOT_DIR		*(rw,no_root_squash)" >> /etc/exports
		echo "Your NFS server may require some configuration changes."
		echo "Consult the man pages for exports, hosts.allow, hosts.deny"
	fi

	echo "Added $BOOT_DIR to /etc/exports"
else
	echo "No change required for NFS export configuration"
fi

if [ "$MACHINE_BASE_DIR" ]; then
  temp=`grep $MACHINE_BASE_DIR /etc/exports`
  if [ ! "$temp" ]; then
	echo "ETC_EXPORTS_MOD=y" >> tmp/bootDirValue
	if [ "$DISTRIBUTION" = "$REDHAT" ]; then
		echo "$MACHINE_BASE_DIR		*(rw,no_root_squash)" >> /etc/exports
	elif [ "$DISTRIBUTION" = "$CALDERA" ]; then
		echo -n "Domain name for the clients which will be be booting from this server: "; read
		echo "$MACHINE_BASE_DIR		*.$REPLY(rw,no_root_squash)" >> /etc/exports
	elif [ "$DISTRIBUTION" = "$TURBO" ]; then
		echo "$MACHINE_BASE_DIR		*(rw,no_root_squash)" >> /etc/exports
		echo "The TurboLinux NFSd package relies upon the /etc/hosts.allow & /etc/hosts.deny"
		echo "files - if you have troubles booting your client, please consult the"
		echo "man pages for exports, hosts.allow, hosts.deny"
	elif [ "$DISTRIBUTION" = "$SUSE" ]; then
		echo "$MACHINE_BASE_DIR		*(rw,no_root_squash)" >> /etc/exports
	elif [ "$DISTRIBUTION" = "$OTHER" ]; then
		echo "$MACHINE_BASE_DIR		*(rw,no_root_squash)" >> /etc/exports
		echo "Your NFS server may require some configuration changes."
		echo "Consult the man pages for exports, hosts.allow, hosts.deny"
	fi

	echo "Added $MACHINE_BASE_DIR to /etc/exports"
  fi
fi

if [ "$PROFILE_BASE_DIR" ]; then
  temp=`grep $PROFILE_BASE_DIR /etc/exports`
  if [ ! "$temp" ]; then
	echo "ETC_EXPORTS_MOD=y" >> tmp/bootDirValue
	if [ "$DISTRIBUTION" = "$REDHAT" ]; then
		echo "$PROFILE_BASE_DIR		*(rw,no_root_squash)" >> /etc/exports
	elif [ "$DISTRIBUTION" = "$CALDERA" ]; then
		echo -n "Domain name for the clients which will be be booting from this server: "; read
		echo "$PROFILE_BASE_DIR		*.$REPLY(rw,no_root_squash)" >> /etc/exports
	elif [ "$DISTRIBUTION" = "$TURBO" ]; then
		echo "$PROFILE_BASE_DIR		*(rw,no_root_squash)" >> /etc/exports
		echo "The TurboLinux NFSd package relies upon the /etc/hosts.allow & /etc/hosts.deny"
		echo "files - if you have troubles booting your client, please consult the"
		echo "man pages for exports, hosts.allow, hosts.deny"
	elif [ "$DISTRIBUTION" = "$SUSE" ]; then
		echo "$PROFILE_BASE_DIR		*(rw,no_root_squash)" >> /etc/exports
	elif [ "$DISTRIBUTION" = "$OTHER" ]; then
		echo "$PROFILE_BASE_DIR		*(rw,no_root_squash)" >> /etc/exports
		echo "Your NFS server may require some configuration changes."
		echo "Consult the man pages for exports, hosts.allow, hosts.deny"
	fi

	echo "Added $PROFILE_BASE_DIR to /etc/exports"
  fi
fi

if [ "$HOME_BASE_DIR" ]; then
  temp=`grep $HOME_BASE_DIR /etc/exports`
  if [ ! "$temp" ]; then
        echo "ETC_EXPORTS_MOD=y" >> tmp/bootDirValue
        if [ "$DISTRIBUTION" = "$REDHAT" ]; then
                echo "$HOME_BASE_DIR         *(rw,no_root_squash)" >> /etc/exports
        elif [ "$DISTRIBUTION" = "$CALDERA" ]; then
                echo -n "Domain name for the clients which will be be booting from this server: "; read
                echo "$HOME_BASE_DIR         *.$REPLY(rw,no_root_squash)" >> /etc/exports
        elif [ "$DISTRIBUTION" = "$TURBO" ]; then
                echo "$HOME_BASE_DIR         *(rw,no_root_squash)" >> /etc/exports
                echo "The TurboLinux NFSd package relies upon the /etc/hosts.allow & /etc/hosts.deny"
                echo "files - if you have troubles booting your client, please consult the"
                echo "man pages for exports, hosts.allow, hosts.deny"
        elif [ "$DISTRIBUTION" = "$SUSE" ]; then
                echo "$HOME_BASE_DIR         *(rw,no_root_squash)" >> /etc/exports
        elif [ "$DISTRIBUTION" = "$OTHER" ]; then
                echo "$HOME_BASE_DIR         *(rw,no_root_squash)" >> /etc/exports
                echo "Your NFS server may require some configuration changes."
                echo "Consult the man pages for exports, hosts.allow, hosts.deny"
        fi

        echo "Added $HOME_BASE_DIR to /etc/exports"
  fi
fi


# =====================================================================================
# Copy the html documentation to the client tree for easy access
# =====================================================================================
cp -pR ../html $BOOT_DIR/IBM/

# =====================================================================================
# Extract the Flash Management Tutorial DOCS
# =====================================================================================
if [ -e /tmp/flash_manage_tutorial.tar.gz ]; then
	echo "Installing the Flash Management Tutorial documents in /IBM"
	tar -C $BOOT_DIR/IBM/ -xzf /tmp/flash_manage_tutorial.tar.gz
	rm -rf /tmp/flash_manage_tutorial.tar.gz
fi

# =====================================================================================
# chmod /usr/bin/smbmount for SMB home directory support
# =====================================================================================
if [ -f $BOOT_DIR/usr/sbin/smbmount ]; then
  chmod u+s $BOOT_DIR/usr/sbin/smbmount
fi

if [ -f $BOOT_DIR/sbin/shutdown ]; then
  chmod 4755 $BOOT_DIR/sbin/shutdown
fi

# make directory for idf's
mkdir -p $BOOT_DIR/mnt/update

umount $cdrom


# ====================================================================================
# Go through and strip anything that is not stripped (this might take a while)
# ====================================================================================

# generate ld.so.cache file...
/sbin/ldconfig -r $BOOT_DIR -C /etc/ld.so.cache.install

ARCH=`uname -m | sed 's/i.86/ix86'/`

echo "Stripping binaries"
if [ "$ARCH" = "ix86" ]; then

   if [ -f strip.list ]; then
      for file in `cat strip.list`
      do
         if [ -f $BOOT_DIR$file ]; then
            Common/scripts/strip $BOOT_DIR$file
         fi
      done
   else
      find $BOOT_DIR -type f | xargs file | grep "not stripped" | grep Intel | grep -v "\.o:" | awk '{print $1}' | sed -n 's/://p' | xargs strip
   fi
else
   echo "Non x86 platform so not stripping binaries."
fi

# create symlink from version of netscape installed to /usr/lib/netscape
if [ -h $BOOT_DIR/usr/lib/netscape ]; then
   rm -f $BOOT_DIR/usr/lib/netscape
fi

NETSCAPE_VERSION=`ls -d $BOOT_DIR/usr/lib/netscape*`
if [ $NETSCAPE_VERSION != "$BOOT_DIR/usr/lib/netscape" ]; then
   LINK=`echo $NETSCAPE_VERSION | tr "/" " " | awk '{print $NF}'`
   ln -s /usr/lib/$LINK $BOOT_DIR/usr/lib/netscape
fi

# create /lib/security symlink
mv $BOOT_DIR/lib/security $BOOT_DIR/usr/lib
rm -Rf $BOOT_DIR/lib/security
ln -sf /usr/lib/security $BOOT_DIR/lib/security 

# Change all references to pam_pwdb.so to pam_unix.so in the configuration files in
# $BOOT_DIR/etc/pam.d ... The pam_pwdb.so module is not cleaning up its file locks
# when booted to a NT system.
for file in `ls $BOOT_DIR/etc/pam.d`; do
   if [ -f "$file" ]; then
      sed s/pwdb/unix/g $BOOT_DIR/etc/pam.d/$file > $BOOT_DIR/etc/pam.d/$file.tmp
      mv -f $BOOT_DIR/etc/pam.d/$file.tmp $BOOT_DIR/etc/pam.d/$file
   fi
done

# Get rid of languages menu in GDM
mv -f $BOOT_DIR/etc/gdm/locale.alias $BOOT_DIR/etc/gdm/locale.alias.orig

# remove FailSafe,Gnome,Twm, Xsession from Sessions menu in GDM by making non-executable.
chmod -x $BOOT_DIR/etc/gdm/Sessions/FailSafe
chmod -x $BOOT_DIR/etc/gdm/Sessions/Gnome
chmod -x $BOOT_DIR/etc/gdm/Sessions/Twm
chmod -x $BOOT_DIR/etc/gdm/Sessions/Xsession

rm -f $BOOT_DIR/etc/gdm/Sessions/XSessionDefault
ln -sf /etc/gdm/Sessions/IceWM $BOOT_DIR/etc/gdm/Sessions/XSessionDefault

echo " "
echo "Client Directory Setup complete"
return 0
}
main_common
