#!/bin/sh
################################################################################
# Name: tl_install.sh
# Purpose: Create a TurboLinux tr
# Command:
#  tl_install.sh
################################################################################

################################################################################
# reboot_Warning
################################################################################
function reboot_Warning
{
	echo "Upon completion of this install, the system must be rebooted."
	echo -n "Do you wish to continue? (Yes/No) "; read
	case $REPLY in
		[yY]|[yY][eE][sS])
			;;
		[nN]|[nN][oO])
			echo ""
			exit 0;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			reboot_Warning;;
	esac
}

################################################################################
# what_client_to_install
################################################################################
function what_client_to_install
{
	echo "Please select the client you wish to install:"
	echo "  1. TurboLinux WorkStation 7.0 (Official IBM distribution) "
	echo "  2. TurboLinux WorkStation 6.0.7 "
        echo -n "Enter Selection: "; read
	case $REPLY in
		[1])
                    . CONFIG/tlw7x.config;;
		[2])
                    . CONFIG/tlw60x.config;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			what_client_to_install;;
	esac
}

function continueQuestion
{
	echo -ne "\nDo you wish to continue? (Yes/No) "
	read input
	case $input in
		[yY]|[yY][eE][sS]) ;;
		[nN]|[nN][oO]) exit;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			continueQuestion;;
	esac
}

################################################################################
# Main Body
################################################################################
function main_body
{
README="/tmp/README.html"
umask 022
set +x
export PATH=/sbin:/usr/sbin:$PATH
# =======  Set Linux distribution specific Variables - used by calling script files ========


# default client info
export CLIENT_VENDOR=TurboLinux

# default RPM list file for the Linux distrubution
# export RPM_LIST_FILE=RPM_LISTS/tlw60x_rpm.list



# ============ Start ======================
# Let's clear the screen to make things cleaner looking
clear
echo -e "\nWelcome to the IBM NetVista Thin Client TurboLinux 7.0 Installer\n"

echo ""
echo "Shutting down nfs server."
if [ -f /etc/rc.d/init.d/nfsserver ]; then
   /etc/rc.d/init.d/nfsserver stop
elif [ -f /etc/rc.d/nfs ]; then
   /etc/rc.d/nfsserver stop
else
   /etc/rc.d/init.d/nfs stop
fi

export CURDIR=`pwd`

TEMP_SCRIPT_LOC=`ps axo command | grep -v grep | grep -v ez | grep -v vi |grep tl_install | cut -f2 -d" " | tr -s "\n" "\t" | cut -f1`
SCRIPT_LOC=${TEMP_SCRIPT_LOC%/*}
cd `dirname $0`


#echo TEMP_SCRIPT_LOC = $TEMP_SCRIPT_LOC
#echo SCRIPT_LOC = $SCRIPT_LOC

# ========== Ask if rebooting is ok =================
# reboot_Warning


# ========== Tell the administrator where the installation log can be found ===========
echo -e "\nAfter the installation has finished, the installation log (install.log) will be"
echo "located in $SCRIPT_LOC/tmp directory"
echo -e " - Please review this file if problems are encountered.\n"

# ========== Ask what client to install =================
#if [ ! -f /tmp/nvltc_type ]; then
#   # Invoked from toolkit - give user a choice
# what_client_to_install
. CONFIG/tlw7x.config
#else
   # Invoked from official build CD - this is a fixed distribution - No choice given
#   . CONFIG/tlw60x.config
# fi
# From the Function what_client_to_install
echo " "
export CLIENT_DISTRIBUTION
export RPM_LIST_FILE
export CLIENT_VENDOR
export NUMCDS

# lets set up the base install steps that a Turbo install would do....
# we just need to know the BOOT_DIR


# ==========  Execute common script file for all client distributions  ====================
Common/scripts/common_install.sh 2>&1 | tee tmp/install.log

# ==========  Be sure the administrator did not exit early ===================
# Need to do a two fold check because of points at which the administrator
# can abort the installation

if [ -f tmp/bootDirValue ]; then
	. tmp/bootDirValue
	if [ ! -e $BOOT_DIR/IBM/linuxDistribution -o -e tmp/error ]; then
		echo -e "\nInstallation aborted\n"
		exit 0
	fi
else
	echo -e "\nInstallation aborted\n"
	exit 0
fi

# ==========  Copy the CD README.html file to the /IBM directory  ====================
if [ -e $README ]; then
	cp $README $BOOT_DIR/IBM/
	rm $README
fi

# this will break NT for now... need to figure out what to do with NT
# NT can't deal with wfica and Wfica in the same directory...
if [ -d $BOOT_DIR/usr/lib/ICAClient ]; then
   mv $BOOT_DIR/usr/lib/ICAClient/wfica $BOOT_DIR/usr/lib/ICAClient/wfica.ibm
   mv $BOOT_DIR/usr/lib/ICAClient/wfcmgr $BOOT_DIR/usr/lib/ICAClient/wfcmgr.ibm
   mv $BOOT_DIR/usr/lib/ICAClient $BOOT_DIR/usr/lib/ICAClient.orig
   ln -s /tmp/ICAClient $BOOT_DIR/usr/lib/ICAClient
   # the ICAClient.orig.tgz file contains the new version of ICA.
   echo "Update ICA to current version(6.30.1050)."
   tar --directory=$BOOT_DIR/usr/lib -zxvf ICAClient.orig.tgz
fi

# Copy the ICA plugin to the netscape directory.
if [ -f $BOOT_DIR/usr/lib/ICAClient.orig/npica.so ]; then
   cp $BOOT_DIR/usr/lib/ICAClient.orig/npica.so $BOOT_DIR/usr/lib/netscape-4.78-2/plugins/npica.so
fi

# ==========  Remove some doc directories since we didn't install docs  ====================
rm -rf $BOOT_DIR/usr/share/doc
rm -rf $BOOT_DIR/usr/X11R6/doc
rm -rf $BOOT_DIR/usr/X11R6/man/ja_JP.ujis
rm -rf $BOOT_DIR/usr/doc
rm -rf $BOOT_DIR/usr/local/doc


#
# Now that the entire image is installed, and the files have been stripped, update
# the installed IDFs in order to report the correct SIZE, CRC, COMPRESSED_SIZE, etc.
# Also creates the intermediate sdfs for the flash images.
#

image_log=tmp/flashImage.log

# First, remove any intermediate sdfs and tars from a previous install
for dir in `find ${BOOT_DIR}/IBM/update/sdf -mindepth 1 -type d -print`
do
        echo "rm -f $dir/*" | tee -a $image_log
        rm -f $dir/*
done

# Create base.cramfs.
# Note: This must be done BEFORE the call to the Java application that updates the IDFs and SDFs
# since base.cramfs is referenced in at least one SDF.
export BOOT_DIR=$BOOT_DIR
mkdir -p ${BOOT_DIR}/IBM/update/base
echo "Creating base.cramfs" | tee -a $image_log
Common/scripts/createBaseCramfs.sh 2>&1 | tee -a $image_log


# Make sure the IDF/SDF tool can access necessary libs & paths.
export LD_LIBRARY_PATH=/usr/local/lib:$LD_LIBRARY_PATH
export PATH=$PATH:/usr/sbin:/usr/bin:/bin:/sbin

# If running on a multiple processor machine, turn off the JIT and increase
# the initial heap size in an attempt to eliminate JVM hangs.
cpus=`grep -c -e '^cpu[0-9]\+' /proc/stat`
echo "Number of CPUs: $cpus" | tee -a $image_log

# we have given up on trying to make UpdateIdf run on dual processor linux machines, pvw 3.14.02
# if more than one processor then skip UpdateIdf and give user notice to run UpdateIdf from one
# server booted client after install if they need flash images
if [ $cpus -gt 1 ] ; then
   echo "Multi-processors have been detected on this computer. The UpdateIdf script will NOT be run" | tee -a $image_log
   echo "because of problems on multi-processor machines. If this installation is going to be a" | tee -a $image_log
   echo "source of flash images for network stations, then run /IBM/bin/UpdateIdf from a xterm window" | tee -a $image_log
   echo "on one server booted (booted from this installation) network station to complete creation of" | tee -a $image_log
   echo "the flash images. Run the program as root (su to root). There should be a minimum of 96mb of" | tee -a $image_log
   echo "memory on network station." | tee -a $image_log

#  the following three lines may have improved but not solved the multi-processor problem
#  export JAVA_COMPILER=NOJIT
#  initial_heap_size="-Xms64m"
#  max_heap_size="-Xmx128m"

else
# The following code updates all SDFs and IDFS and creates the intermediate SDF tar files
# needed for flash recovery.
echo "chroot ${BOOT_DIR} /opt/IBMJava2-13/jre/bin/java $initial_heap_size $max_heap_size -cp /IBM/update/LCMT.jar UpdateIDF /IBM/update/idf /IBM/update/sdf" | tee -a $image_log
chroot ${BOOT_DIR} /opt/IBMJava2-13/jre/bin/java $initial_heap_size $max_heap_size -cp /IBM/update/LCMT.jar UpdateIDF /IBM/update/idf /IBM/update/sdf 2>&1 | tee -a $image_log
fi

# Create the base image files, base_2x00.tgz, and base_n70.tgz
export BOOT_DIR=$BOOT_DIR
Common/scripts/createBase.sh 2>&1 | tee -a $image_log

# End of code to create flash recovery tar files


# ==========   DONE - Time to reboot  ====================
echo -e "\nInstallation is Complete - Remove the $CLIENT_VENDOR CD\n"
echo -e "Restarting nfs daemon\n"
echo ""

if [ -f /etc/rc.d/init.d/nfsserver ]; then
   /etc/rc.d/init.d/nfsserver stop
   /etc/rc.d/init.d/nfsserver start
elif [ -f /etc/rc.d/nfs ]; then
   /etc/rc.d/nfsserver stop
   /etc/rc.d/nfsserver start
else
   /etc/rc.d/init.d/nfs stop
   /etc/rc.d/init.d/nfs start
fi
}
main_body
