/*
 *
 *   PAM to libsmb authentication interface functions.
 *   Based on code from client.c
 *   Copyright (C) Andrew Tridgell 1994-1998
 *   Copyright (c) International Business Machines  Corp., 2001
 *     IBM Contact: RCHNSSPT@us.ibm.com
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#define NO_SYSLOG

#include "includes.h"
#include "pam_cifs_util.h"

//struct cli_state *cli=NULL;
extern BOOL in_client;
static int port = SMB_PORT;
pstring cur_dir = "\\";
pstring cd_path = "";
//static pstring service;
//static pstring desthost;
extern pstring global_myname;
//static pstring password;
//static pstring username;
static pstring workgroup;
extern struct in_addr ipzero;

static int name_type = 0x20;
static int max_protocol = PROTOCOL_NT1;

// Local prototypes
static int process_tok(fstring tok);
static void cmd_help(void);

/* 30 second timeout on most commands */
//#define CLIENT_TIMEOUT (30*1000)
//#define SHORT_TIMEOUT (5*1000)

extern pstring debugf;
extern int DEBUGLEVEL;
static BOOL have_ip;
struct in_addr dest_ip;

/* timing globals */
int get_total_size = 0;
int get_total_time_ms = 0;
int put_total_size = 0;
int put_total_time_ms = 0;

#define USENMB


/****************************************************************************
Connect to server
****************************************************************************/
int _cifs_verify_password(char* wg, char* server, const char* username, const char* password)
{
    int retval = CIFS_UTIL_UNKNOWN_ERROR; // Prime return value
    struct cli_state *c=NULL;
    struct nmb_name called, calling;
    struct in_addr ip;
    extern struct in_addr ipzero;

    // Convert names to nmb format
    make_nmb_name(&calling, global_myname, 0x0);
    make_nmb_name(&called , server, name_type);

 again:
    ip = ipzero;
    //if (have_ip) ip = dest_ip;

    /* have to open a new connection */
    if (!(c=cli_initialise(NULL)) || (cli_set_port(c, port) == 0) ||
        !cli_connect(c, server, &ip)) {
        DEBUG(3,("Connection to server %s failed.\n", server));

        retval = CIFS_UTIL_NOT_AVAILABLE_ERROR;
        goto EXIT;
    }

    // Request a session with the server
    c->protocol = max_protocol;
    if (!cli_session_request(c, &calling, &called)) {
        char *p;
        DEBUG(3,("Session request to server %s failed: (%s)\n", 
              called.name, cli_errstr(c)));
        cli_shutdown(c);
        free(c);
        c = NULL;

        //tpp?? What is this for?  eliminate domain from name?
        if ((p=strchr(called.name, '.'))) {
            *p = 0;
            goto again;
        }

        //tpp?? What is this for?  Connect to default smb name
        if (strcmp(called.name, "*SMBSERVER")) {
            make_nmb_name(&called , "*SMBSERVER", 0x20);
            goto again;
        }

        // Request failed, return
        retval = CIFS_UTIL_NOT_AVAILABLE_ERROR;
        goto EXIT;
    }

    // Negotiate protocol
    if (!cli_negprot(c)) {
        DEBUG(0,("Protocol negotiation failed.\n"));

        retval = CIFS_UTIL_NOT_AVAILABLE_ERROR;
        goto EXIT;
    }

    // Establish authenticated session
    if (!cli_session_setup(c, (char *) username, 
                   (char *) password, strlen(password),
                   (char *) password, strlen(password),
                   wg)) {

        uint8 errclass;
        uint32 errnum;
        uint32 nt_rpc_error;


        // Get cli error class and code
        cli_error(c, &errclass, &errnum, &nt_rpc_error);
        //printf("Error class=%.2x, num=%.2x, nt_rpc_error=%.2x\n", errclass, 
        //       errnum, nt_rpc_error);

        // Check for expired password
        if ((errclass == CIFS_UTIL_ERRSRV_CLASS) && 
            (errnum == CIFS_UTIL_ERRSRV_PASSWORD_EXPIRED))
        {
            retval = CIFS_UTIL_PASSWORD_EXPIRED_ERROR;
        }
        else
        {
            DEBUG(0,("Session setup to server %s failed: %s\n", 
                     called.name, cli_errstr(c)));
            retval = CIFS_UTIL_AUTH_ERROR;
        }

        goto EXIT;
    }

    // Do not allow a login that defaulted to type guest.  This is to prevent
    // a user logging on with an undefined user name that matches the guest
    // password if the guest account is enabled.
    // printf("checking for guest, action=%d\n", SVAL(c->inbuf, CIFS_UTIL_SMB_ACTION));
	if ((SVAL(c->inbuf, CIFS_UTIL_SMB_ACTION) & CIFS_UTIL_SMB_ACTION_GUEST_LOGIN))
    {
        DEBUG(5,("Guest login detected for user %s - not allowed\n", username));
        retval = CIFS_UTIL_AUTH_ERROR;
        goto EXIT;
    }

    if (*c->server_domain || *c->server_os || *c->server_type)
        DEBUG(1,("Domain=[%s] OS=[%s] Server=[%s]\n",
            c->server_domain,c->server_os,c->server_type));

    // Authentication successful, set return value
    DEBUG(2,("Authenticated session established to %s\n", server));
    retval = CIFS_UTIL_SUCCESS;

EXIT:
   // Clean up  
   if (c != NULL)
   {
      cli_shutdown(c);
      free(c);
      // c = NULL;
   }

   return retval;
}


int _cifs_authenticate_user(char *wg, char* server, const char* username, 
                            const char* password)
{
    int retval = CIFS_UTIL_UNKNOWN_ERROR;
    fstring base_directory;
    char *pname = "pam_cifs_util";
    extern char *optarg;
    extern int optind;
    int old_debug;
    pstring query_host;
    static pstring servicesf = CONFIGFILE;
    pstring term_code;
    pstring new_name_resolve_order;

    *term_code = 0;

    *query_host = 0;
    *base_directory = 0;

    *new_name_resolve_order = 0;

    DEBUGLEVEL = 2;
 
    setup_logging(pname,True);

    have_ip = FALSE;

    charset_initialise();

    in_client = True;   /* Make sure that we tell lp_load we are */

    old_debug = DEBUGLEVEL;
    if (!lp_load(servicesf,True,False,False)) {
        fprintf(stderr, "Can't load %s - run testparm to debug it\n", servicesf);
    }
    DEBUGLEVEL = old_debug;
    
    codepage_initialise(lp_client_code_page());

    pstrcpy(workgroup,lp_workgroup());
    get_myname((*global_myname)?NULL:global_myname);  

    DEBUG( 3, ( "Client started (version %s).\n", VERSION ) );

    retval = _cifs_verify_password(wg, server, username, password);

EXIT:
    return retval;
}


int _cifs_change_password(char *server, const char *username, 
                           char *pass_old, char *pass_new)
{
    int retval = CIFS_UTIL_UNKNOWN_ERROR;
    fstring base_directory;
    char *pname = "pam_cifs_util";
    extern char *optarg;
    extern int optind;
    int old_debug;
    pstring query_host;
    static pstring servicesf = CONFIGFILE;
    pstring term_code;
    pstring new_name_resolve_order;

    char err_str[25];
    int err_str_len = 25; 

    *term_code = 0;

    *query_host = 0;
    *base_directory = 0;

    *new_name_resolve_order = 0;

    DEBUGLEVEL = 2;
 
    setup_logging(pname,True);

    have_ip = FALSE;

    charset_initialise();

    in_client = True;   /* Make sure that we tell lp_load we are */

    old_debug = DEBUGLEVEL;
    if (!lp_load(servicesf,True,False,False)) {
        fprintf(stderr, "Can't load %s - run testparm to debug it\n", servicesf);
    }
    DEBUGLEVEL = old_debug;//??tpp
    
    codepage_initialise(lp_client_code_page());

    pstrcpy(workgroup,lp_workgroup());
    get_myname((*global_myname)?NULL:global_myname);  

    DEBUG( 3, ( "Client started (version %s).\n", VERSION ) );

    /* Attempt to change the password */
    if(remote_password_change(server, username, pass_old, pass_new,
                              err_str, err_str_len))
    {
        retval = CIFS_UTIL_SUCCESS;
    }
    else
    {
        retval = CIFS_UTIL_PASSWORD_CHANGE_ERROR;
    }
    
    return retval;
}

