/*
 *
 * PAM to libsmb authentication interface functions.
 *   Copyright (c) International Business Machines  Corp., 2001
 *     IBM Contact: RCHNSSPT@us.ibm.com
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */


/* SMB Lib errors
 * These are SMB error codes that should be defined in samba somewhere but
 * I cannot find them. */
#define CIFS_UTIL_ERRSRV_CLASS 2
#define CIFS_UTIL_ERRSRV_PASSWORD_EXPIRED   2242

/* Additional smb packet definitions */

/* Session setup and X response definitions */
#define CIFS_UTIL_SMB_ACTION smb_vwv2            /* Action field */
#define CIFS_UTIL_SMB_ACTION_GUEST_LOGIN 0x01    /*   Guest indicator in action */


/* Error constants */
typedef enum {
    CIFS_UTIL_SUCCESS               = 0,
    CIFS_UTIL_UNKNOWN_ERROR         = 1,
    CIFS_UTIL_NOT_AVAILABLE_ERROR   = 2,
    CIFS_UTIL_AUTH_ERROR            = 3,
    CIFS_UTIL_PASSWORD_CHANGE_ERROR = 4,
    CIFS_UTIL_PASSWORD_EXPIRED_ERROR = 5
} pamCifsUtilErrorCodes;

/* Local prototypes */
int _cifs_verify_password(char *wg,
                          char *server,
                          const char *username, 
                          const char *password);

int _cifs_authenticate_user(char *wg, 
                            char *server, 
                            const char *username, 
                            const char *password);

int _cifs_change_password(char *server,
                          const char *username, 
                          char *old_password,
                          char *new_password);
